# coding: utf-8

"""
    NetSuite REST API

    NetSuite REST Record API generated 2023-01-18 at 19:40:11 UTC for account 472052, user will@theapiguys.com with role Keap Integration.  # noqa: E501

    OpenAPI spec version: v1
    Contact: info@netsuite.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Contact(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'custentity_national_ins_no': 'str',
        'custentity_our_reference': 'str',
        'custentity_comm_pref_sms': 'bool',
        'custentity_mm_stopsendingsms': 'bool',
        'custentity_ufh_approv_trng_details': 'str',
        'custentity_trainer_rating': 'int',
        'custentity_other_tech_quals': 'str',
        'custentityhp_approv_trng_details': 'str',
        'custentityka_type': 'str',
        'id': 'str',
        'custentity_ufh_qual_details': 'str',
        'fax': 'str',
        'custentity_solar_trng_details': 'str',
        'custentity_neceic_scheme_yn': 'bool',
        'custentity_sol_qual_details': 'str',
        'date_created': 'datetime',
        'custentity_water_regs_1999': 'bool',
        'last_name': 'str',
        'custentity_mm_lastoptinkeyword': 'str',
        'phone': 'str',
        'custentity_2_photographs': 'bool',
        'custentity_mm_lastsmsmessage': 'str',
        'custentity_health_safety_heights': 'bool',
        'custentitysolar_trng_yn': 'bool',
        'custentity_sales_rep_title': 'str',
        'custentity_signature_image': 'str',
        'custentity_pv_installed_before': 'bool',
        'custentity_ufh_instll_prev_yn': 'bool',
        'custentity_training_info_reqd': 'str',
        'custentity_neceic_qualifications': 'str',
        'custentity_other_electrical': 'str',
        'custentity_conf_2yrs_indexp': 'bool',
        'custentity_pv_qual': 'bool',
        'custentity_legacy_num': 'str',
        'custentity_uln': 'str',
        'assistant_phone': 'str',
        'email': 'str',
        'is_private': 'bool',
        'custentity_photo_recd': 'bool',
        'custentity_hp_approv_trng_yn': 'bool',
        'custentity_17th_edition': 'bool',
        'custentity_solar_instll_prev_yn': 'bool',
        'custentity_pv_systems': 'str',
        'custentity_mm_iskeylinkentity': 'bool',
        'custom_form': 'ContactCustomForm',
        'custentity_cust_cat_type': 'str',
        'custentity_geographical_cover': 'str',
        'custentity_cv_dob': 'date',
        'external_id': 'str',
        'entity_id': 'str',
        'custentity_ufh_approv_training': 'bool',
        'custentity_g3_hws_qualification_yn': 'bool',
        'custentity_med_diet_spec_req': 'str',
        'custentity_number_of_units': 'int',
        'custentity_comm_pref_email': 'bool',
        'custentity_test_entity': 'bool',
        'mobile_phone': 'str',
        'custentity_pre_requisites_certs': 'bool',
        'custentity_ph_nvq3': 'bool',
        'custentity_salutation_workaround': 'str',
        'custentity_mcs_number': 'str',
        'global_subscription_status': 'CustomerGlobalSubscriptionStatus',
        'custentity_ph_nvq2': 'bool',
        'custentity_send_emp_sms': 'bool',
        'alt_email': 'str',
        'custentityniceic_accreditation_date': 'date',
        'custentity_hp_qual_details': 'str',
        'salutation': 'str',
        'custentity_hp_instll_prev_yn': 'bool',
        'custentity_website_qr_number': 'str',
        'custentity_feedback_completed': 'bool',
        'is_inactive': 'bool',
        'first_name': 'str',
        'home_phone': 'str',
        'custentity_mm_smsreplystatus': 'str',
        'custentity_pv_qual_details': 'str',
        'custentityent_mobile_phone': 'str',
        'custentity_health_safety_coshh': 'bool',
        'title': 'str',
        'custentity_nat_ins': 'str',
        'custentityka_ranking': 'int',
        'custentity_health_safety_man_hdling': 'bool',
        'custentity_dob': 'date',
        'custentity_sales_rep_email': 'str',
        'owner': 'int',
        'comments': 'str',
        'last_modified_date': 'datetime',
        'custentity_send_emp_email': 'bool',
        'middle_name': 'str',
        'custentity_resubscribestatus': 'str',
        'custentity_learning_needs': 'str',
        'custentity_future_of_business': 'str',
        'custentity_no_engineers': 'int',
        'custentity_course_comments': 'str',
        'office_phone': 'str',
        'custentity_ri_partp_reg': 'bool',
        'supervisor_phone': 'str',
        'ref_name': 'str',
        'links': 'list[NsLink]',
        'custentity_pv_course_atteneded': 'OneOfcontactCustentityPvCourseAtteneded',
        'contact_campaign_event': 'NsResource',
        'custentity_further_training_offer': 'NsResourceCollection',
        'supervisor': 'Contact',
        'company': 'OneOfcontactCompany',
        'contact_source': 'NsResource',
        'image': 'NsResource',
        'custentity_scope_of_business': 'NsResource',
        'custentity_dietry_requirements': 'NsResource',
        'custentity_heat_pump_training': 'NsResource',
        'assistant': 'Contact',
        'contact_source_campaign_category': 'NsResource',
        'custentity_course_attended': 'OneOfcontactCustentityCourseAttended',
        'custentity_sol_course_attended': 'OneOfcontactCustentitySolCourseAttended',
        'custentity_water_regulations_1999': 'OneOfcontactCustentityWaterRegulations1999',
        'custentity_cust_instll_training': 'NsResource',
        'custentityent_bestcontact': 'NsResource',
        'custentity_energy_eff_attended': 'OneOfcontactCustentityEnergyEffAttended',
        'custentity_ethnic_group': 'NsResource',
        'custentity_unvent_hot_water_g3': 'OneOfcontactCustentityUnventHotWaterG3',
        'category': 'NsResourceCollection',
        'custentity_hp_course_attended': 'OneOfcontactCustentityHpCourseAttended',
        'custentity_mm_lastsmssentby': 'NsResource',
        'custentity_hitachi_course_attended': 'OneOfcontactCustentityHitachiCourseAttended',
        'subsidiary': 'NsResource'
    }

    attribute_map = {
        'custentity_national_ins_no': 'custentity_national_ins_no',
        'custentity_our_reference': 'custentity_our_reference',
        'custentity_comm_pref_sms': 'custentity_comm_pref_sms',
        'custentity_mm_stopsendingsms': 'custentity_mm_stopsendingsms',
        'custentity_ufh_approv_trng_details': 'custentity_ufh_approv_trng_details',
        'custentity_trainer_rating': 'custentity_trainer_rating',
        'custentity_other_tech_quals': 'custentity_other_tech_quals',
        'custentityhp_approv_trng_details': 'custentityhp_approv_trng_details',
        'custentityka_type': 'custentityka_type',
        'id': 'id',
        'custentity_ufh_qual_details': 'custentity_ufh_qual_details',
        'fax': 'fax',
        'custentity_solar_trng_details': 'custentity_solar_trng_details',
        'custentity_neceic_scheme_yn': 'custentity_neceic_scheme_yn',
        'custentity_sol_qual_details': 'custentity_sol_qual_details',
        'date_created': 'dateCreated',
        'custentity_water_regs_1999': 'custentity_water_regs_1999',
        'last_name': 'lastName',
        'custentity_mm_lastoptinkeyword': 'custentity_mm_lastoptinkeyword',
        'phone': 'phone',
        'custentity_2_photographs': 'custentity_2_photographs',
        'custentity_mm_lastsmsmessage': 'custentity_mm_lastsmsmessage',
        'custentity_health_safety_heights': 'custentity_health_safety_heights',
        'custentitysolar_trng_yn': 'custentitysolar_trng_yn',
        'custentity_sales_rep_title': 'custentity_sales_rep_title',
        'custentity_signature_image': 'custentity_signature_image',
        'custentity_pv_installed_before': 'custentity_pv_installed_before',
        'custentity_ufh_instll_prev_yn': 'custentity_ufh_instll_prev_yn',
        'custentity_training_info_reqd': 'custentity_training_info_reqd',
        'custentity_neceic_qualifications': 'custentity_neceic_qualifications',
        'custentity_other_electrical': 'custentity_other_electrical',
        'custentity_conf_2yrs_indexp': 'custentity_conf_2yrs_indexp',
        'custentity_pv_qual': 'custentity_pv_qual',
        'custentity_legacy_num': 'custentity_legacy_num',
        'custentity_uln': 'custentity_uln',
        'assistant_phone': 'assistantPhone',
        'email': 'email',
        'is_private': 'isPrivate',
        'custentity_photo_recd': 'custentity_photo_recd',
        'custentity_hp_approv_trng_yn': 'custentity_hp_approv_trng_yn',
        'custentity_17th_edition': 'custentity_17th_edition',
        'custentity_solar_instll_prev_yn': 'custentity_solar_instll_prev_yn',
        'custentity_pv_systems': 'custentity_pv_systems',
        'custentity_mm_iskeylinkentity': 'custentity_mm_iskeylinkentity',
        'custom_form': 'customForm',
        'custentity_cust_cat_type': 'custentity_cust_cat_type',
        'custentity_geographical_cover': 'custentity_geographical_cover',
        'custentity_cv_dob': 'custentity_cv_dob',
        'external_id': 'externalId',
        'entity_id': 'entityId',
        'custentity_ufh_approv_training': 'custentity_ufh_approv_training',
        'custentity_g3_hws_qualification_yn': 'custentity_g3_hws_qualification_yn',
        'custentity_med_diet_spec_req': 'custentity_med_diet_spec_req',
        'custentity_number_of_units': 'custentity_number_of_units',
        'custentity_comm_pref_email': 'custentity_comm_pref_email',
        'custentity_test_entity': 'custentity_test_entity',
        'mobile_phone': 'mobilePhone',
        'custentity_pre_requisites_certs': 'custentity_pre_requisites_certs',
        'custentity_ph_nvq3': 'custentity_ph_nvq3',
        'custentity_salutation_workaround': 'custentity_salutation_workaround',
        'custentity_mcs_number': 'custentity_mcs_number',
        'global_subscription_status': 'globalSubscriptionStatus',
        'custentity_ph_nvq2': 'custentity_ph_nvq2',
        'custentity_send_emp_sms': 'custentity_send_emp_sms',
        'alt_email': 'altEmail',
        'custentityniceic_accreditation_date': 'custentityniceic_accreditation_date',
        'custentity_hp_qual_details': 'custentity_hp_qual_details',
        'salutation': 'salutation',
        'custentity_hp_instll_prev_yn': 'custentity_hp_instll_prev_yn',
        'custentity_website_qr_number': 'custentity_website_qr_number',
        'custentity_feedback_completed': 'custentity_feedback_completed',
        'is_inactive': 'isInactive',
        'first_name': 'firstName',
        'home_phone': 'homePhone',
        'custentity_mm_smsreplystatus': 'custentity_mm_smsreplystatus',
        'custentity_pv_qual_details': 'custentity_pv_qual_details',
        'custentityent_mobile_phone': 'custentityent_mobile_phone',
        'custentity_health_safety_coshh': 'custentity_health_safety_coshh',
        'title': 'title',
        'custentity_nat_ins': 'custentity_nat_ins',
        'custentityka_ranking': 'custentityka_ranking',
        'custentity_health_safety_man_hdling': 'custentity_health_safety_man_hdling',
        'custentity_dob': 'custentity_dob',
        'custentity_sales_rep_email': 'custentity_sales_rep_email',
        'owner': 'owner',
        'comments': 'comments',
        'last_modified_date': 'lastModifiedDate',
        'custentity_send_emp_email': 'custentity_send_emp_email',
        'middle_name': 'middleName',
        'custentity_resubscribestatus': 'custentity_resubscribestatus',
        'custentity_learning_needs': 'custentity_learning_needs',
        'custentity_future_of_business': 'custentity_future_of_business',
        'custentity_no_engineers': 'custentity_no_engineers',
        'custentity_course_comments': 'custentity_course_comments',
        'office_phone': 'officePhone',
        'custentity_ri_partp_reg': 'custentity_ri_partp_reg',
        'supervisor_phone': 'supervisorPhone',
        'ref_name': 'refName',
        'links': 'links',
        'custentity_pv_course_atteneded': 'custentity_pv_course_atteneded',
        'contact_campaign_event': 'contactCampaignEvent',
        'custentity_further_training_offer': 'custentity_further_training_offer',
        'supervisor': 'supervisor',
        'company': 'company',
        'contact_source': 'contactSource',
        'image': 'image',
        'custentity_scope_of_business': 'custentity_scope_of_business',
        'custentity_dietry_requirements': 'custentity_dietry_requirements',
        'custentity_heat_pump_training': 'custentity_heat_pump_training',
        'assistant': 'assistant',
        'contact_source_campaign_category': 'contactSourceCampaignCategory',
        'custentity_course_attended': 'custentity_course_attended',
        'custentity_sol_course_attended': 'custentity_sol_course_attended',
        'custentity_water_regulations_1999': 'custentity_water_regulations_1999',
        'custentity_cust_instll_training': 'custentity_cust_instll_training',
        'custentityent_bestcontact': 'custentityent_bestcontact',
        'custentity_energy_eff_attended': 'custentity_energy_eff_attended',
        'custentity_ethnic_group': 'custentity_ethnic_group',
        'custentity_unvent_hot_water_g3': 'custentity_unvent_hot_water_g3',
        'category': 'category',
        'custentity_hp_course_attended': 'custentity_hp_course_attended',
        'custentity_mm_lastsmssentby': 'custentity_mm_lastsmssentby',
        'custentity_hitachi_course_attended': 'custentity_hitachi_course_attended',
        'subsidiary': 'subsidiary'
    }

    def __init__(self, custentity_national_ins_no=None, custentity_our_reference=None, custentity_comm_pref_sms=None, custentity_mm_stopsendingsms=None, custentity_ufh_approv_trng_details=None, custentity_trainer_rating=None, custentity_other_tech_quals=None, custentityhp_approv_trng_details=None, custentityka_type=None, id=None, custentity_ufh_qual_details=None, fax=None, custentity_solar_trng_details=None, custentity_neceic_scheme_yn=None, custentity_sol_qual_details=None, date_created=None, custentity_water_regs_1999=None, last_name=None, custentity_mm_lastoptinkeyword=None, phone=None, custentity_2_photographs=None, custentity_mm_lastsmsmessage=None, custentity_health_safety_heights=None, custentitysolar_trng_yn=None, custentity_sales_rep_title=None, custentity_signature_image=None, custentity_pv_installed_before=None, custentity_ufh_instll_prev_yn=None, custentity_training_info_reqd=None, custentity_neceic_qualifications=None, custentity_other_electrical=None, custentity_conf_2yrs_indexp=None, custentity_pv_qual=None, custentity_legacy_num=None, custentity_uln=None, assistant_phone=None, email=None, is_private=None, custentity_photo_recd=None, custentity_hp_approv_trng_yn=None, custentity_17th_edition=None, custentity_solar_instll_prev_yn=None, custentity_pv_systems=None, custentity_mm_iskeylinkentity=None, custom_form=None, custentity_cust_cat_type=None, custentity_geographical_cover=None, custentity_cv_dob=None, external_id=None, entity_id=None, custentity_ufh_approv_training=None, custentity_g3_hws_qualification_yn=None, custentity_med_diet_spec_req=None, custentity_number_of_units=None, custentity_comm_pref_email=None, custentity_test_entity=None, mobile_phone=None, custentity_pre_requisites_certs=None, custentity_ph_nvq3=None, custentity_salutation_workaround=None, custentity_mcs_number=None, global_subscription_status=None, custentity_ph_nvq2=None, custentity_send_emp_sms=None, alt_email=None, custentityniceic_accreditation_date=None, custentity_hp_qual_details=None, salutation=None, custentity_hp_instll_prev_yn=None, custentity_website_qr_number=None, custentity_feedback_completed=None, is_inactive=None, first_name=None, home_phone=None, custentity_mm_smsreplystatus=None, custentity_pv_qual_details=None, custentityent_mobile_phone=None, custentity_health_safety_coshh=None, title=None, custentity_nat_ins=None, custentityka_ranking=None, custentity_health_safety_man_hdling=None, custentity_dob=None, custentity_sales_rep_email=None, owner=None, comments=None, last_modified_date=None, custentity_send_emp_email=None, middle_name=None, custentity_resubscribestatus=None, custentity_learning_needs=None, custentity_future_of_business=None, custentity_no_engineers=None, custentity_course_comments=None, office_phone=None, custentity_ri_partp_reg=None, supervisor_phone=None, ref_name=None, links=None, custentity_pv_course_atteneded=None, contact_campaign_event=None, custentity_further_training_offer=None, supervisor=None, company=None, contact_source=None, image=None, custentity_scope_of_business=None, custentity_dietry_requirements=None, custentity_heat_pump_training=None, assistant=None, contact_source_campaign_category=None, custentity_course_attended=None, custentity_sol_course_attended=None, custentity_water_regulations_1999=None, custentity_cust_instll_training=None, custentityent_bestcontact=None, custentity_energy_eff_attended=None, custentity_ethnic_group=None, custentity_unvent_hot_water_g3=None, category=None, custentity_hp_course_attended=None, custentity_mm_lastsmssentby=None, custentity_hitachi_course_attended=None, subsidiary=None):  # noqa: E501
        """Contact - a model defined in Swagger"""  # noqa: E501
        self._custentity_national_ins_no = None
        self._custentity_our_reference = None
        self._custentity_comm_pref_sms = None
        self._custentity_mm_stopsendingsms = None
        self._custentity_ufh_approv_trng_details = None
        self._custentity_trainer_rating = None
        self._custentity_other_tech_quals = None
        self._custentityhp_approv_trng_details = None
        self._custentityka_type = None
        self._id = None
        self._custentity_ufh_qual_details = None
        self._fax = None
        self._custentity_solar_trng_details = None
        self._custentity_neceic_scheme_yn = None
        self._custentity_sol_qual_details = None
        self._date_created = None
        self._custentity_water_regs_1999 = None
        self._last_name = None
        self._custentity_mm_lastoptinkeyword = None
        self._phone = None
        self._custentity_2_photographs = None
        self._custentity_mm_lastsmsmessage = None
        self._custentity_health_safety_heights = None
        self._custentitysolar_trng_yn = None
        self._custentity_sales_rep_title = None
        self._custentity_signature_image = None
        self._custentity_pv_installed_before = None
        self._custentity_ufh_instll_prev_yn = None
        self._custentity_training_info_reqd = None
        self._custentity_neceic_qualifications = None
        self._custentity_other_electrical = None
        self._custentity_conf_2yrs_indexp = None
        self._custentity_pv_qual = None
        self._custentity_legacy_num = None
        self._custentity_uln = None
        self._assistant_phone = None
        self._email = None
        self._is_private = None
        self._custentity_photo_recd = None
        self._custentity_hp_approv_trng_yn = None
        self._custentity_17th_edition = None
        self._custentity_solar_instll_prev_yn = None
        self._custentity_pv_systems = None
        self._custentity_mm_iskeylinkentity = None
        self._custom_form = None
        self._custentity_cust_cat_type = None
        self._custentity_geographical_cover = None
        self._custentity_cv_dob = None
        self._external_id = None
        self._entity_id = None
        self._custentity_ufh_approv_training = None
        self._custentity_g3_hws_qualification_yn = None
        self._custentity_med_diet_spec_req = None
        self._custentity_number_of_units = None
        self._custentity_comm_pref_email = None
        self._custentity_test_entity = None
        self._mobile_phone = None
        self._custentity_pre_requisites_certs = None
        self._custentity_ph_nvq3 = None
        self._custentity_salutation_workaround = None
        self._custentity_mcs_number = None
        self._global_subscription_status = None
        self._custentity_ph_nvq2 = None
        self._custentity_send_emp_sms = None
        self._alt_email = None
        self._custentityniceic_accreditation_date = None
        self._custentity_hp_qual_details = None
        self._salutation = None
        self._custentity_hp_instll_prev_yn = None
        self._custentity_website_qr_number = None
        self._custentity_feedback_completed = None
        self._is_inactive = None
        self._first_name = None
        self._home_phone = None
        self._custentity_mm_smsreplystatus = None
        self._custentity_pv_qual_details = None
        self._custentityent_mobile_phone = None
        self._custentity_health_safety_coshh = None
        self._title = None
        self._custentity_nat_ins = None
        self._custentityka_ranking = None
        self._custentity_health_safety_man_hdling = None
        self._custentity_dob = None
        self._custentity_sales_rep_email = None
        self._owner = None
        self._comments = None
        self._last_modified_date = None
        self._custentity_send_emp_email = None
        self._middle_name = None
        self._custentity_resubscribestatus = None
        self._custentity_learning_needs = None
        self._custentity_future_of_business = None
        self._custentity_no_engineers = None
        self._custentity_course_comments = None
        self._office_phone = None
        self._custentity_ri_partp_reg = None
        self._supervisor_phone = None
        self._ref_name = None
        self._links = None
        self._custentity_pv_course_atteneded = None
        self._contact_campaign_event = None
        self._custentity_further_training_offer = None
        self._supervisor = None
        self._company = None
        self._contact_source = None
        self._image = None
        self._custentity_scope_of_business = None
        self._custentity_dietry_requirements = None
        self._custentity_heat_pump_training = None
        self._assistant = None
        self._contact_source_campaign_category = None
        self._custentity_course_attended = None
        self._custentity_sol_course_attended = None
        self._custentity_water_regulations_1999 = None
        self._custentity_cust_instll_training = None
        self._custentityent_bestcontact = None
        self._custentity_energy_eff_attended = None
        self._custentity_ethnic_group = None
        self._custentity_unvent_hot_water_g3 = None
        self._category = None
        self._custentity_hp_course_attended = None
        self._custentity_mm_lastsmssentby = None
        self._custentity_hitachi_course_attended = None
        self._subsidiary = None
        self.discriminator = None
        if custentity_national_ins_no is not None:
            self.custentity_national_ins_no = custentity_national_ins_no
        if custentity_our_reference is not None:
            self.custentity_our_reference = custentity_our_reference
        if custentity_comm_pref_sms is not None:
            self.custentity_comm_pref_sms = custentity_comm_pref_sms
        if custentity_mm_stopsendingsms is not None:
            self.custentity_mm_stopsendingsms = custentity_mm_stopsendingsms
        if custentity_ufh_approv_trng_details is not None:
            self.custentity_ufh_approv_trng_details = custentity_ufh_approv_trng_details
        if custentity_trainer_rating is not None:
            self.custentity_trainer_rating = custentity_trainer_rating
        if custentity_other_tech_quals is not None:
            self.custentity_other_tech_quals = custentity_other_tech_quals
        if custentityhp_approv_trng_details is not None:
            self.custentityhp_approv_trng_details = custentityhp_approv_trng_details
        if custentityka_type is not None:
            self.custentityka_type = custentityka_type
        if id is not None:
            self.id = id
        if custentity_ufh_qual_details is not None:
            self.custentity_ufh_qual_details = custentity_ufh_qual_details
        if fax is not None:
            self.fax = fax
        if custentity_solar_trng_details is not None:
            self.custentity_solar_trng_details = custentity_solar_trng_details
        if custentity_neceic_scheme_yn is not None:
            self.custentity_neceic_scheme_yn = custentity_neceic_scheme_yn
        if custentity_sol_qual_details is not None:
            self.custentity_sol_qual_details = custentity_sol_qual_details
        if date_created is not None:
            self.date_created = date_created
        if custentity_water_regs_1999 is not None:
            self.custentity_water_regs_1999 = custentity_water_regs_1999
        if last_name is not None:
            self.last_name = last_name
        if custentity_mm_lastoptinkeyword is not None:
            self.custentity_mm_lastoptinkeyword = custentity_mm_lastoptinkeyword
        if phone is not None:
            self.phone = phone
        if custentity_2_photographs is not None:
            self.custentity_2_photographs = custentity_2_photographs
        if custentity_mm_lastsmsmessage is not None:
            self.custentity_mm_lastsmsmessage = custentity_mm_lastsmsmessage
        if custentity_health_safety_heights is not None:
            self.custentity_health_safety_heights = custentity_health_safety_heights
        if custentitysolar_trng_yn is not None:
            self.custentitysolar_trng_yn = custentitysolar_trng_yn
        if custentity_sales_rep_title is not None:
            self.custentity_sales_rep_title = custentity_sales_rep_title
        if custentity_signature_image is not None:
            self.custentity_signature_image = custentity_signature_image
        if custentity_pv_installed_before is not None:
            self.custentity_pv_installed_before = custentity_pv_installed_before
        if custentity_ufh_instll_prev_yn is not None:
            self.custentity_ufh_instll_prev_yn = custentity_ufh_instll_prev_yn
        if custentity_training_info_reqd is not None:
            self.custentity_training_info_reqd = custentity_training_info_reqd
        if custentity_neceic_qualifications is not None:
            self.custentity_neceic_qualifications = custentity_neceic_qualifications
        if custentity_other_electrical is not None:
            self.custentity_other_electrical = custentity_other_electrical
        if custentity_conf_2yrs_indexp is not None:
            self.custentity_conf_2yrs_indexp = custentity_conf_2yrs_indexp
        if custentity_pv_qual is not None:
            self.custentity_pv_qual = custentity_pv_qual
        if custentity_legacy_num is not None:
            self.custentity_legacy_num = custentity_legacy_num
        if custentity_uln is not None:
            self.custentity_uln = custentity_uln
        if assistant_phone is not None:
            self.assistant_phone = assistant_phone
        if email is not None:
            self.email = email
        if is_private is not None:
            self.is_private = is_private
        if custentity_photo_recd is not None:
            self.custentity_photo_recd = custentity_photo_recd
        if custentity_hp_approv_trng_yn is not None:
            self.custentity_hp_approv_trng_yn = custentity_hp_approv_trng_yn
        if custentity_17th_edition is not None:
            self.custentity_17th_edition = custentity_17th_edition
        if custentity_solar_instll_prev_yn is not None:
            self.custentity_solar_instll_prev_yn = custentity_solar_instll_prev_yn
        if custentity_pv_systems is not None:
            self.custentity_pv_systems = custentity_pv_systems
        if custentity_mm_iskeylinkentity is not None:
            self.custentity_mm_iskeylinkentity = custentity_mm_iskeylinkentity
        if custom_form is not None:
            self.custom_form = custom_form
        if custentity_cust_cat_type is not None:
            self.custentity_cust_cat_type = custentity_cust_cat_type
        if custentity_geographical_cover is not None:
            self.custentity_geographical_cover = custentity_geographical_cover
        if custentity_cv_dob is not None:
            self.custentity_cv_dob = custentity_cv_dob
        if external_id is not None:
            self.external_id = external_id
        if entity_id is not None:
            self.entity_id = entity_id
        if custentity_ufh_approv_training is not None:
            self.custentity_ufh_approv_training = custentity_ufh_approv_training
        if custentity_g3_hws_qualification_yn is not None:
            self.custentity_g3_hws_qualification_yn = custentity_g3_hws_qualification_yn
        if custentity_med_diet_spec_req is not None:
            self.custentity_med_diet_spec_req = custentity_med_diet_spec_req
        if custentity_number_of_units is not None:
            self.custentity_number_of_units = custentity_number_of_units
        if custentity_comm_pref_email is not None:
            self.custentity_comm_pref_email = custentity_comm_pref_email
        if custentity_test_entity is not None:
            self.custentity_test_entity = custentity_test_entity
        if mobile_phone is not None:
            self.mobile_phone = mobile_phone
        if custentity_pre_requisites_certs is not None:
            self.custentity_pre_requisites_certs = custentity_pre_requisites_certs
        if custentity_ph_nvq3 is not None:
            self.custentity_ph_nvq3 = custentity_ph_nvq3
        if custentity_salutation_workaround is not None:
            self.custentity_salutation_workaround = custentity_salutation_workaround
        if custentity_mcs_number is not None:
            self.custentity_mcs_number = custentity_mcs_number
        if global_subscription_status is not None:
            self.global_subscription_status = global_subscription_status
        if custentity_ph_nvq2 is not None:
            self.custentity_ph_nvq2 = custentity_ph_nvq2
        if custentity_send_emp_sms is not None:
            self.custentity_send_emp_sms = custentity_send_emp_sms
        if alt_email is not None:
            self.alt_email = alt_email
        if custentityniceic_accreditation_date is not None:
            self.custentityniceic_accreditation_date = custentityniceic_accreditation_date
        if custentity_hp_qual_details is not None:
            self.custentity_hp_qual_details = custentity_hp_qual_details
        if salutation is not None:
            self.salutation = salutation
        if custentity_hp_instll_prev_yn is not None:
            self.custentity_hp_instll_prev_yn = custentity_hp_instll_prev_yn
        if custentity_website_qr_number is not None:
            self.custentity_website_qr_number = custentity_website_qr_number
        if custentity_feedback_completed is not None:
            self.custentity_feedback_completed = custentity_feedback_completed
        if is_inactive is not None:
            self.is_inactive = is_inactive
        if first_name is not None:
            self.first_name = first_name
        if home_phone is not None:
            self.home_phone = home_phone
        if custentity_mm_smsreplystatus is not None:
            self.custentity_mm_smsreplystatus = custentity_mm_smsreplystatus
        if custentity_pv_qual_details is not None:
            self.custentity_pv_qual_details = custentity_pv_qual_details
        if custentityent_mobile_phone is not None:
            self.custentityent_mobile_phone = custentityent_mobile_phone
        if custentity_health_safety_coshh is not None:
            self.custentity_health_safety_coshh = custentity_health_safety_coshh
        if title is not None:
            self.title = title
        if custentity_nat_ins is not None:
            self.custentity_nat_ins = custentity_nat_ins
        if custentityka_ranking is not None:
            self.custentityka_ranking = custentityka_ranking
        if custentity_health_safety_man_hdling is not None:
            self.custentity_health_safety_man_hdling = custentity_health_safety_man_hdling
        if custentity_dob is not None:
            self.custentity_dob = custentity_dob
        if custentity_sales_rep_email is not None:
            self.custentity_sales_rep_email = custentity_sales_rep_email
        if owner is not None:
            self.owner = owner
        if comments is not None:
            self.comments = comments
        if last_modified_date is not None:
            self.last_modified_date = last_modified_date
        if custentity_send_emp_email is not None:
            self.custentity_send_emp_email = custentity_send_emp_email
        if middle_name is not None:
            self.middle_name = middle_name
        if custentity_resubscribestatus is not None:
            self.custentity_resubscribestatus = custentity_resubscribestatus
        if custentity_learning_needs is not None:
            self.custentity_learning_needs = custentity_learning_needs
        if custentity_future_of_business is not None:
            self.custentity_future_of_business = custentity_future_of_business
        if custentity_no_engineers is not None:
            self.custentity_no_engineers = custentity_no_engineers
        if custentity_course_comments is not None:
            self.custentity_course_comments = custentity_course_comments
        if office_phone is not None:
            self.office_phone = office_phone
        if custentity_ri_partp_reg is not None:
            self.custentity_ri_partp_reg = custentity_ri_partp_reg
        if supervisor_phone is not None:
            self.supervisor_phone = supervisor_phone
        if ref_name is not None:
            self.ref_name = ref_name
        if links is not None:
            self.links = links
        if custentity_pv_course_atteneded is not None:
            self.custentity_pv_course_atteneded = custentity_pv_course_atteneded
        if contact_campaign_event is not None:
            self.contact_campaign_event = contact_campaign_event
        if custentity_further_training_offer is not None:
            self.custentity_further_training_offer = custentity_further_training_offer
        if supervisor is not None:
            self.supervisor = supervisor
        if company is not None:
            self.company = company
        if contact_source is not None:
            self.contact_source = contact_source
        if image is not None:
            self.image = image
        if custentity_scope_of_business is not None:
            self.custentity_scope_of_business = custentity_scope_of_business
        if custentity_dietry_requirements is not None:
            self.custentity_dietry_requirements = custentity_dietry_requirements
        if custentity_heat_pump_training is not None:
            self.custentity_heat_pump_training = custentity_heat_pump_training
        if assistant is not None:
            self.assistant = assistant
        if contact_source_campaign_category is not None:
            self.contact_source_campaign_category = contact_source_campaign_category
        if custentity_course_attended is not None:
            self.custentity_course_attended = custentity_course_attended
        if custentity_sol_course_attended is not None:
            self.custentity_sol_course_attended = custentity_sol_course_attended
        if custentity_water_regulations_1999 is not None:
            self.custentity_water_regulations_1999 = custentity_water_regulations_1999
        if custentity_cust_instll_training is not None:
            self.custentity_cust_instll_training = custentity_cust_instll_training
        if custentityent_bestcontact is not None:
            self.custentityent_bestcontact = custentityent_bestcontact
        if custentity_energy_eff_attended is not None:
            self.custentity_energy_eff_attended = custentity_energy_eff_attended
        if custentity_ethnic_group is not None:
            self.custentity_ethnic_group = custentity_ethnic_group
        if custentity_unvent_hot_water_g3 is not None:
            self.custentity_unvent_hot_water_g3 = custentity_unvent_hot_water_g3
        if category is not None:
            self.category = category
        if custentity_hp_course_attended is not None:
            self.custentity_hp_course_attended = custentity_hp_course_attended
        if custentity_mm_lastsmssentby is not None:
            self.custentity_mm_lastsmssentby = custentity_mm_lastsmssentby
        if custentity_hitachi_course_attended is not None:
            self.custentity_hitachi_course_attended = custentity_hitachi_course_attended
        if subsidiary is not None:
            self.subsidiary = subsidiary

    @property
    def custentity_national_ins_no(self):
        """Gets the custentity_national_ins_no of this Contact.  # noqa: E501


        :return: The custentity_national_ins_no of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_national_ins_no

    @custentity_national_ins_no.setter
    def custentity_national_ins_no(self, custentity_national_ins_no):
        """Sets the custentity_national_ins_no of this Contact.


        :param custentity_national_ins_no: The custentity_national_ins_no of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_national_ins_no = custentity_national_ins_no

    @property
    def custentity_our_reference(self):
        """Gets the custentity_our_reference of this Contact.  # noqa: E501


        :return: The custentity_our_reference of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_our_reference

    @custentity_our_reference.setter
    def custentity_our_reference(self, custentity_our_reference):
        """Sets the custentity_our_reference of this Contact.


        :param custentity_our_reference: The custentity_our_reference of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_our_reference = custentity_our_reference

    @property
    def custentity_comm_pref_sms(self):
        """Gets the custentity_comm_pref_sms of this Contact.  # noqa: E501


        :return: The custentity_comm_pref_sms of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_comm_pref_sms

    @custentity_comm_pref_sms.setter
    def custentity_comm_pref_sms(self, custentity_comm_pref_sms):
        """Sets the custentity_comm_pref_sms of this Contact.


        :param custentity_comm_pref_sms: The custentity_comm_pref_sms of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_comm_pref_sms = custentity_comm_pref_sms

    @property
    def custentity_mm_stopsendingsms(self):
        """Gets the custentity_mm_stopsendingsms of this Contact.  # noqa: E501


        :return: The custentity_mm_stopsendingsms of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_mm_stopsendingsms

    @custentity_mm_stopsendingsms.setter
    def custentity_mm_stopsendingsms(self, custentity_mm_stopsendingsms):
        """Sets the custentity_mm_stopsendingsms of this Contact.


        :param custentity_mm_stopsendingsms: The custentity_mm_stopsendingsms of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_mm_stopsendingsms = custentity_mm_stopsendingsms

    @property
    def custentity_ufh_approv_trng_details(self):
        """Gets the custentity_ufh_approv_trng_details of this Contact.  # noqa: E501


        :return: The custentity_ufh_approv_trng_details of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_ufh_approv_trng_details

    @custentity_ufh_approv_trng_details.setter
    def custentity_ufh_approv_trng_details(self, custentity_ufh_approv_trng_details):
        """Sets the custentity_ufh_approv_trng_details of this Contact.


        :param custentity_ufh_approv_trng_details: The custentity_ufh_approv_trng_details of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_ufh_approv_trng_details = custentity_ufh_approv_trng_details

    @property
    def custentity_trainer_rating(self):
        """Gets the custentity_trainer_rating of this Contact.  # noqa: E501


        :return: The custentity_trainer_rating of this Contact.  # noqa: E501
        :rtype: int
        """
        return self._custentity_trainer_rating

    @custentity_trainer_rating.setter
    def custentity_trainer_rating(self, custentity_trainer_rating):
        """Sets the custentity_trainer_rating of this Contact.


        :param custentity_trainer_rating: The custentity_trainer_rating of this Contact.  # noqa: E501
        :type: int
        """

        self._custentity_trainer_rating = custentity_trainer_rating

    @property
    def custentity_other_tech_quals(self):
        """Gets the custentity_other_tech_quals of this Contact.  # noqa: E501


        :return: The custentity_other_tech_quals of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_other_tech_quals

    @custentity_other_tech_quals.setter
    def custentity_other_tech_quals(self, custentity_other_tech_quals):
        """Sets the custentity_other_tech_quals of this Contact.


        :param custentity_other_tech_quals: The custentity_other_tech_quals of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_other_tech_quals = custentity_other_tech_quals

    @property
    def custentityhp_approv_trng_details(self):
        """Gets the custentityhp_approv_trng_details of this Contact.  # noqa: E501


        :return: The custentityhp_approv_trng_details of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentityhp_approv_trng_details

    @custentityhp_approv_trng_details.setter
    def custentityhp_approv_trng_details(self, custentityhp_approv_trng_details):
        """Sets the custentityhp_approv_trng_details of this Contact.


        :param custentityhp_approv_trng_details: The custentityhp_approv_trng_details of this Contact.  # noqa: E501
        :type: str
        """

        self._custentityhp_approv_trng_details = custentityhp_approv_trng_details

    @property
    def custentityka_type(self):
        """Gets the custentityka_type of this Contact.  # noqa: E501


        :return: The custentityka_type of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentityka_type

    @custentityka_type.setter
    def custentityka_type(self, custentityka_type):
        """Sets the custentityka_type of this Contact.


        :param custentityka_type: The custentityka_type of this Contact.  # noqa: E501
        :type: str
        """

        self._custentityka_type = custentityka_type

    @property
    def id(self):
        """Gets the id of this Contact.  # noqa: E501

        The internal ID for this record is shown here. If you do not want to show internal IDs, clear the Show Internal IDs box at Home &gt; Set Preferences.  # noqa: E501

        :return: The id of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Contact.

        The internal ID for this record is shown here. If you do not want to show internal IDs, clear the Show Internal IDs box at Home &gt; Set Preferences.  # noqa: E501

        :param id: The id of this Contact.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def custentity_ufh_qual_details(self):
        """Gets the custentity_ufh_qual_details of this Contact.  # noqa: E501


        :return: The custentity_ufh_qual_details of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_ufh_qual_details

    @custentity_ufh_qual_details.setter
    def custentity_ufh_qual_details(self, custentity_ufh_qual_details):
        """Sets the custentity_ufh_qual_details of this Contact.


        :param custentity_ufh_qual_details: The custentity_ufh_qual_details of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_ufh_qual_details = custentity_ufh_qual_details

    @property
    def fax(self):
        """Gets the fax of this Contact.  # noqa: E501

        Enter a fax number for this record. You should enter the fax number exactly as it must be dialed. If a &apos;1&apos; is required to fax to this number, be sure to include it at the beginning of the number. The number you enter automatically appears in the To Be Faxed field of transactions when you select this customer. To fax NetSuite forms, an administrator must first set up fax service at Setup &gt; Set Up Printing, Fax and E-mail &gt; Fax.  # noqa: E501

        :return: The fax of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._fax

    @fax.setter
    def fax(self, fax):
        """Sets the fax of this Contact.

        Enter a fax number for this record. You should enter the fax number exactly as it must be dialed. If a &apos;1&apos; is required to fax to this number, be sure to include it at the beginning of the number. The number you enter automatically appears in the To Be Faxed field of transactions when you select this customer. To fax NetSuite forms, an administrator must first set up fax service at Setup &gt; Set Up Printing, Fax and E-mail &gt; Fax.  # noqa: E501

        :param fax: The fax of this Contact.  # noqa: E501
        :type: str
        """

        self._fax = fax

    @property
    def custentity_solar_trng_details(self):
        """Gets the custentity_solar_trng_details of this Contact.  # noqa: E501


        :return: The custentity_solar_trng_details of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_solar_trng_details

    @custentity_solar_trng_details.setter
    def custentity_solar_trng_details(self, custentity_solar_trng_details):
        """Sets the custentity_solar_trng_details of this Contact.


        :param custentity_solar_trng_details: The custentity_solar_trng_details of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_solar_trng_details = custentity_solar_trng_details

    @property
    def custentity_neceic_scheme_yn(self):
        """Gets the custentity_neceic_scheme_yn of this Contact.  # noqa: E501


        :return: The custentity_neceic_scheme_yn of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_neceic_scheme_yn

    @custentity_neceic_scheme_yn.setter
    def custentity_neceic_scheme_yn(self, custentity_neceic_scheme_yn):
        """Sets the custentity_neceic_scheme_yn of this Contact.


        :param custentity_neceic_scheme_yn: The custentity_neceic_scheme_yn of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_neceic_scheme_yn = custentity_neceic_scheme_yn

    @property
    def custentity_sol_qual_details(self):
        """Gets the custentity_sol_qual_details of this Contact.  # noqa: E501


        :return: The custentity_sol_qual_details of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_sol_qual_details

    @custentity_sol_qual_details.setter
    def custentity_sol_qual_details(self, custentity_sol_qual_details):
        """Sets the custentity_sol_qual_details of this Contact.


        :param custentity_sol_qual_details: The custentity_sol_qual_details of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_sol_qual_details = custentity_sol_qual_details

    @property
    def date_created(self):
        """Gets the date_created of this Contact.  # noqa: E501

        In this field, NetSuite automatically records the date you created this record.  # noqa: E501

        :return: The date_created of this Contact.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this Contact.

        In this field, NetSuite automatically records the date you created this record.  # noqa: E501

        :param date_created: The date_created of this Contact.  # noqa: E501
        :type: datetime
        """

        self._date_created = date_created

    @property
    def custentity_water_regs_1999(self):
        """Gets the custentity_water_regs_1999 of this Contact.  # noqa: E501


        :return: The custentity_water_regs_1999 of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_water_regs_1999

    @custentity_water_regs_1999.setter
    def custentity_water_regs_1999(self, custentity_water_regs_1999):
        """Sets the custentity_water_regs_1999 of this Contact.


        :param custentity_water_regs_1999: The custentity_water_regs_1999 of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_water_regs_1999 = custentity_water_regs_1999

    @property
    def last_name(self):
        """Gets the last_name of this Contact.  # noqa: E501

        Enter the contact&apos;s last name. What you enter here automatically appears last in the Contact field. This field is required for the Online Bill Pay feature.  # noqa: E501

        :return: The last_name of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this Contact.

        Enter the contact&apos;s last name. What you enter here automatically appears last in the Contact field. This field is required for the Online Bill Pay feature.  # noqa: E501

        :param last_name: The last_name of this Contact.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def custentity_mm_lastoptinkeyword(self):
        """Gets the custentity_mm_lastoptinkeyword of this Contact.  # noqa: E501


        :return: The custentity_mm_lastoptinkeyword of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_mm_lastoptinkeyword

    @custentity_mm_lastoptinkeyword.setter
    def custentity_mm_lastoptinkeyword(self, custentity_mm_lastoptinkeyword):
        """Sets the custentity_mm_lastoptinkeyword of this Contact.


        :param custentity_mm_lastoptinkeyword: The custentity_mm_lastoptinkeyword of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_mm_lastoptinkeyword = custentity_mm_lastoptinkeyword

    @property
    def phone(self):
        """Gets the phone of this Contact.  # noqa: E501

        Enter the phone number you primarily use to reach this contact. This number appears in the Contacts list and in the Contact section of company records. This field is required for the Online Bill Pay feature.  # noqa: E501

        :return: The phone of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this Contact.

        Enter the phone number you primarily use to reach this contact. This number appears in the Contacts list and in the Contact section of company records. This field is required for the Online Bill Pay feature.  # noqa: E501

        :param phone: The phone of this Contact.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def custentity_2_photographs(self):
        """Gets the custentity_2_photographs of this Contact.  # noqa: E501


        :return: The custentity_2_photographs of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_2_photographs

    @custentity_2_photographs.setter
    def custentity_2_photographs(self, custentity_2_photographs):
        """Sets the custentity_2_photographs of this Contact.


        :param custentity_2_photographs: The custentity_2_photographs of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_2_photographs = custentity_2_photographs

    @property
    def custentity_mm_lastsmsmessage(self):
        """Gets the custentity_mm_lastsmsmessage of this Contact.  # noqa: E501


        :return: The custentity_mm_lastsmsmessage of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_mm_lastsmsmessage

    @custentity_mm_lastsmsmessage.setter
    def custentity_mm_lastsmsmessage(self, custentity_mm_lastsmsmessage):
        """Sets the custentity_mm_lastsmsmessage of this Contact.


        :param custentity_mm_lastsmsmessage: The custentity_mm_lastsmsmessage of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_mm_lastsmsmessage = custentity_mm_lastsmsmessage

    @property
    def custentity_health_safety_heights(self):
        """Gets the custentity_health_safety_heights of this Contact.  # noqa: E501


        :return: The custentity_health_safety_heights of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_health_safety_heights

    @custentity_health_safety_heights.setter
    def custentity_health_safety_heights(self, custentity_health_safety_heights):
        """Sets the custentity_health_safety_heights of this Contact.


        :param custentity_health_safety_heights: The custentity_health_safety_heights of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_health_safety_heights = custentity_health_safety_heights

    @property
    def custentitysolar_trng_yn(self):
        """Gets the custentitysolar_trng_yn of this Contact.  # noqa: E501


        :return: The custentitysolar_trng_yn of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentitysolar_trng_yn

    @custentitysolar_trng_yn.setter
    def custentitysolar_trng_yn(self, custentitysolar_trng_yn):
        """Sets the custentitysolar_trng_yn of this Contact.


        :param custentitysolar_trng_yn: The custentitysolar_trng_yn of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentitysolar_trng_yn = custentitysolar_trng_yn

    @property
    def custentity_sales_rep_title(self):
        """Gets the custentity_sales_rep_title of this Contact.  # noqa: E501


        :return: The custentity_sales_rep_title of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_sales_rep_title

    @custentity_sales_rep_title.setter
    def custentity_sales_rep_title(self, custentity_sales_rep_title):
        """Sets the custentity_sales_rep_title of this Contact.


        :param custentity_sales_rep_title: The custentity_sales_rep_title of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_sales_rep_title = custentity_sales_rep_title

    @property
    def custentity_signature_image(self):
        """Gets the custentity_signature_image of this Contact.  # noqa: E501


        :return: The custentity_signature_image of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_signature_image

    @custentity_signature_image.setter
    def custentity_signature_image(self, custentity_signature_image):
        """Sets the custentity_signature_image of this Contact.


        :param custentity_signature_image: The custentity_signature_image of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_signature_image = custentity_signature_image

    @property
    def custentity_pv_installed_before(self):
        """Gets the custentity_pv_installed_before of this Contact.  # noqa: E501


        :return: The custentity_pv_installed_before of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_pv_installed_before

    @custentity_pv_installed_before.setter
    def custentity_pv_installed_before(self, custentity_pv_installed_before):
        """Sets the custentity_pv_installed_before of this Contact.


        :param custentity_pv_installed_before: The custentity_pv_installed_before of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_pv_installed_before = custentity_pv_installed_before

    @property
    def custentity_ufh_instll_prev_yn(self):
        """Gets the custentity_ufh_instll_prev_yn of this Contact.  # noqa: E501


        :return: The custentity_ufh_instll_prev_yn of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_ufh_instll_prev_yn

    @custentity_ufh_instll_prev_yn.setter
    def custentity_ufh_instll_prev_yn(self, custentity_ufh_instll_prev_yn):
        """Sets the custentity_ufh_instll_prev_yn of this Contact.


        :param custentity_ufh_instll_prev_yn: The custentity_ufh_instll_prev_yn of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_ufh_instll_prev_yn = custentity_ufh_instll_prev_yn

    @property
    def custentity_training_info_reqd(self):
        """Gets the custentity_training_info_reqd of this Contact.  # noqa: E501


        :return: The custentity_training_info_reqd of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_training_info_reqd

    @custentity_training_info_reqd.setter
    def custentity_training_info_reqd(self, custentity_training_info_reqd):
        """Sets the custentity_training_info_reqd of this Contact.


        :param custentity_training_info_reqd: The custentity_training_info_reqd of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_training_info_reqd = custentity_training_info_reqd

    @property
    def custentity_neceic_qualifications(self):
        """Gets the custentity_neceic_qualifications of this Contact.  # noqa: E501


        :return: The custentity_neceic_qualifications of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_neceic_qualifications

    @custentity_neceic_qualifications.setter
    def custentity_neceic_qualifications(self, custentity_neceic_qualifications):
        """Sets the custentity_neceic_qualifications of this Contact.


        :param custentity_neceic_qualifications: The custentity_neceic_qualifications of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_neceic_qualifications = custentity_neceic_qualifications

    @property
    def custentity_other_electrical(self):
        """Gets the custentity_other_electrical of this Contact.  # noqa: E501


        :return: The custentity_other_electrical of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_other_electrical

    @custentity_other_electrical.setter
    def custentity_other_electrical(self, custentity_other_electrical):
        """Sets the custentity_other_electrical of this Contact.


        :param custentity_other_electrical: The custentity_other_electrical of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_other_electrical = custentity_other_electrical

    @property
    def custentity_conf_2yrs_indexp(self):
        """Gets the custentity_conf_2yrs_indexp of this Contact.  # noqa: E501


        :return: The custentity_conf_2yrs_indexp of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_conf_2yrs_indexp

    @custentity_conf_2yrs_indexp.setter
    def custentity_conf_2yrs_indexp(self, custentity_conf_2yrs_indexp):
        """Sets the custentity_conf_2yrs_indexp of this Contact.


        :param custentity_conf_2yrs_indexp: The custentity_conf_2yrs_indexp of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_conf_2yrs_indexp = custentity_conf_2yrs_indexp

    @property
    def custentity_pv_qual(self):
        """Gets the custentity_pv_qual of this Contact.  # noqa: E501


        :return: The custentity_pv_qual of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_pv_qual

    @custentity_pv_qual.setter
    def custentity_pv_qual(self, custentity_pv_qual):
        """Sets the custentity_pv_qual of this Contact.


        :param custentity_pv_qual: The custentity_pv_qual of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_pv_qual = custentity_pv_qual

    @property
    def custentity_legacy_num(self):
        """Gets the custentity_legacy_num of this Contact.  # noqa: E501


        :return: The custentity_legacy_num of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_legacy_num

    @custentity_legacy_num.setter
    def custentity_legacy_num(self, custentity_legacy_num):
        """Sets the custentity_legacy_num of this Contact.


        :param custentity_legacy_num: The custentity_legacy_num of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_legacy_num = custentity_legacy_num

    @property
    def custentity_uln(self):
        """Gets the custentity_uln of this Contact.  # noqa: E501


        :return: The custentity_uln of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_uln

    @custentity_uln.setter
    def custentity_uln(self, custentity_uln):
        """Sets the custentity_uln of this Contact.


        :param custentity_uln: The custentity_uln of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_uln = custentity_uln

    @property
    def assistant_phone(self):
        """Gets the assistant_phone of this Contact.  # noqa: E501

        Enter the phone number for this contact&apos;s assistant. This number appears only on this record.  # noqa: E501

        :return: The assistant_phone of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._assistant_phone

    @assistant_phone.setter
    def assistant_phone(self, assistant_phone):
        """Sets the assistant_phone of this Contact.

        Enter the phone number for this contact&apos;s assistant. This number appears only on this record.  # noqa: E501

        :param assistant_phone: The assistant_phone of this Contact.  # noqa: E501
        :type: str
        """

        self._assistant_phone = assistant_phone

    @property
    def email(self):
        """Gets the email of this Contact.  # noqa: E501

        Enter the contact&apos;s e-mail address. If you enter an e-mail address, you can e-mail this contact directly from the Contacts list. Also, If you invite this contact to an event, the contact receives e-mail with the event details.  # noqa: E501

        :return: The email of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Contact.

        Enter the contact&apos;s e-mail address. If you enter an e-mail address, you can e-mail this contact directly from the Contacts list. Also, If you invite this contact to an event, the contact receives e-mail with the event details.  # noqa: E501

        :param email: The email of this Contact.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def is_private(self):
        """Gets the is_private of this Contact.  # noqa: E501

        Check this box if this is a private contact. Private contacts can only be viewed by the person that entered the contact record. They are also excluded from the Duplicate Detection process.  # noqa: E501

        :return: The is_private of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._is_private

    @is_private.setter
    def is_private(self, is_private):
        """Sets the is_private of this Contact.

        Check this box if this is a private contact. Private contacts can only be viewed by the person that entered the contact record. They are also excluded from the Duplicate Detection process.  # noqa: E501

        :param is_private: The is_private of this Contact.  # noqa: E501
        :type: bool
        """

        self._is_private = is_private

    @property
    def custentity_photo_recd(self):
        """Gets the custentity_photo_recd of this Contact.  # noqa: E501


        :return: The custentity_photo_recd of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_photo_recd

    @custentity_photo_recd.setter
    def custentity_photo_recd(self, custentity_photo_recd):
        """Sets the custentity_photo_recd of this Contact.


        :param custentity_photo_recd: The custentity_photo_recd of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_photo_recd = custentity_photo_recd

    @property
    def custentity_hp_approv_trng_yn(self):
        """Gets the custentity_hp_approv_trng_yn of this Contact.  # noqa: E501


        :return: The custentity_hp_approv_trng_yn of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_hp_approv_trng_yn

    @custentity_hp_approv_trng_yn.setter
    def custentity_hp_approv_trng_yn(self, custentity_hp_approv_trng_yn):
        """Sets the custentity_hp_approv_trng_yn of this Contact.


        :param custentity_hp_approv_trng_yn: The custentity_hp_approv_trng_yn of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_hp_approv_trng_yn = custentity_hp_approv_trng_yn

    @property
    def custentity_17th_edition(self):
        """Gets the custentity_17th_edition of this Contact.  # noqa: E501


        :return: The custentity_17th_edition of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_17th_edition

    @custentity_17th_edition.setter
    def custentity_17th_edition(self, custentity_17th_edition):
        """Sets the custentity_17th_edition of this Contact.


        :param custentity_17th_edition: The custentity_17th_edition of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_17th_edition = custentity_17th_edition

    @property
    def custentity_solar_instll_prev_yn(self):
        """Gets the custentity_solar_instll_prev_yn of this Contact.  # noqa: E501


        :return: The custentity_solar_instll_prev_yn of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_solar_instll_prev_yn

    @custentity_solar_instll_prev_yn.setter
    def custentity_solar_instll_prev_yn(self, custentity_solar_instll_prev_yn):
        """Sets the custentity_solar_instll_prev_yn of this Contact.


        :param custentity_solar_instll_prev_yn: The custentity_solar_instll_prev_yn of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_solar_instll_prev_yn = custentity_solar_instll_prev_yn

    @property
    def custentity_pv_systems(self):
        """Gets the custentity_pv_systems of this Contact.  # noqa: E501


        :return: The custentity_pv_systems of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_pv_systems

    @custentity_pv_systems.setter
    def custentity_pv_systems(self, custentity_pv_systems):
        """Sets the custentity_pv_systems of this Contact.


        :param custentity_pv_systems: The custentity_pv_systems of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_pv_systems = custentity_pv_systems

    @property
    def custentity_mm_iskeylinkentity(self):
        """Gets the custentity_mm_iskeylinkentity of this Contact.  # noqa: E501


        :return: The custentity_mm_iskeylinkentity of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_mm_iskeylinkentity

    @custentity_mm_iskeylinkentity.setter
    def custentity_mm_iskeylinkentity(self, custentity_mm_iskeylinkentity):
        """Sets the custentity_mm_iskeylinkentity of this Contact.


        :param custentity_mm_iskeylinkentity: The custentity_mm_iskeylinkentity of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_mm_iskeylinkentity = custentity_mm_iskeylinkentity

    @property
    def custom_form(self):
        """Gets the custom_form of this Contact.  # noqa: E501


        :return: The custom_form of this Contact.  # noqa: E501
        :rtype: ContactCustomForm
        """
        return self._custom_form

    @custom_form.setter
    def custom_form(self, custom_form):
        """Sets the custom_form of this Contact.


        :param custom_form: The custom_form of this Contact.  # noqa: E501
        :type: ContactCustomForm
        """

        self._custom_form = custom_form

    @property
    def custentity_cust_cat_type(self):
        """Gets the custentity_cust_cat_type of this Contact.  # noqa: E501


        :return: The custentity_cust_cat_type of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_cust_cat_type

    @custentity_cust_cat_type.setter
    def custentity_cust_cat_type(self, custentity_cust_cat_type):
        """Sets the custentity_cust_cat_type of this Contact.


        :param custentity_cust_cat_type: The custentity_cust_cat_type of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_cust_cat_type = custentity_cust_cat_type

    @property
    def custentity_geographical_cover(self):
        """Gets the custentity_geographical_cover of this Contact.  # noqa: E501


        :return: The custentity_geographical_cover of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_geographical_cover

    @custentity_geographical_cover.setter
    def custentity_geographical_cover(self, custentity_geographical_cover):
        """Sets the custentity_geographical_cover of this Contact.


        :param custentity_geographical_cover: The custentity_geographical_cover of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_geographical_cover = custentity_geographical_cover

    @property
    def custentity_cv_dob(self):
        """Gets the custentity_cv_dob of this Contact.  # noqa: E501


        :return: The custentity_cv_dob of this Contact.  # noqa: E501
        :rtype: date
        """
        return self._custentity_cv_dob

    @custentity_cv_dob.setter
    def custentity_cv_dob(self, custentity_cv_dob):
        """Sets the custentity_cv_dob of this Contact.


        :param custentity_cv_dob: The custentity_cv_dob of this Contact.  # noqa: E501
        :type: date
        """

        self._custentity_cv_dob = custentity_cv_dob

    @property
    def external_id(self):
        """Gets the external_id of this Contact.  # noqa: E501


        :return: The external_id of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this Contact.


        :param external_id: The external_id of this Contact.  # noqa: E501
        :type: str
        """

        self._external_id = external_id

    @property
    def entity_id(self):
        """Gets the entity_id of this Contact.  # noqa: E501

        NetSuite automatically completes this field as you enter first, middle, and last names below. This is how the contact&apos;s name appears in all lists.  # noqa: E501

        :return: The entity_id of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this Contact.

        NetSuite automatically completes this field as you enter first, middle, and last names below. This is how the contact&apos;s name appears in all lists.  # noqa: E501

        :param entity_id: The entity_id of this Contact.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    @property
    def custentity_ufh_approv_training(self):
        """Gets the custentity_ufh_approv_training of this Contact.  # noqa: E501


        :return: The custentity_ufh_approv_training of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_ufh_approv_training

    @custentity_ufh_approv_training.setter
    def custentity_ufh_approv_training(self, custentity_ufh_approv_training):
        """Sets the custentity_ufh_approv_training of this Contact.


        :param custentity_ufh_approv_training: The custentity_ufh_approv_training of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_ufh_approv_training = custentity_ufh_approv_training

    @property
    def custentity_g3_hws_qualification_yn(self):
        """Gets the custentity_g3_hws_qualification_yn of this Contact.  # noqa: E501


        :return: The custentity_g3_hws_qualification_yn of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_g3_hws_qualification_yn

    @custentity_g3_hws_qualification_yn.setter
    def custentity_g3_hws_qualification_yn(self, custentity_g3_hws_qualification_yn):
        """Sets the custentity_g3_hws_qualification_yn of this Contact.


        :param custentity_g3_hws_qualification_yn: The custentity_g3_hws_qualification_yn of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_g3_hws_qualification_yn = custentity_g3_hws_qualification_yn

    @property
    def custentity_med_diet_spec_req(self):
        """Gets the custentity_med_diet_spec_req of this Contact.  # noqa: E501


        :return: The custentity_med_diet_spec_req of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_med_diet_spec_req

    @custentity_med_diet_spec_req.setter
    def custentity_med_diet_spec_req(self, custentity_med_diet_spec_req):
        """Sets the custentity_med_diet_spec_req of this Contact.


        :param custentity_med_diet_spec_req: The custentity_med_diet_spec_req of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_med_diet_spec_req = custentity_med_diet_spec_req

    @property
    def custentity_number_of_units(self):
        """Gets the custentity_number_of_units of this Contact.  # noqa: E501


        :return: The custentity_number_of_units of this Contact.  # noqa: E501
        :rtype: int
        """
        return self._custentity_number_of_units

    @custentity_number_of_units.setter
    def custentity_number_of_units(self, custentity_number_of_units):
        """Sets the custentity_number_of_units of this Contact.


        :param custentity_number_of_units: The custentity_number_of_units of this Contact.  # noqa: E501
        :type: int
        """

        self._custentity_number_of_units = custentity_number_of_units

    @property
    def custentity_comm_pref_email(self):
        """Gets the custentity_comm_pref_email of this Contact.  # noqa: E501


        :return: The custentity_comm_pref_email of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_comm_pref_email

    @custentity_comm_pref_email.setter
    def custentity_comm_pref_email(self, custentity_comm_pref_email):
        """Sets the custentity_comm_pref_email of this Contact.


        :param custentity_comm_pref_email: The custentity_comm_pref_email of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_comm_pref_email = custentity_comm_pref_email

    @property
    def custentity_test_entity(self):
        """Gets the custentity_test_entity of this Contact.  # noqa: E501


        :return: The custentity_test_entity of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_test_entity

    @custentity_test_entity.setter
    def custentity_test_entity(self, custentity_test_entity):
        """Sets the custentity_test_entity of this Contact.


        :param custentity_test_entity: The custentity_test_entity of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_test_entity = custentity_test_entity

    @property
    def mobile_phone(self):
        """Gets the mobile_phone of this Contact.  # noqa: E501

        Enter the contact&apos;s mobile or cell phone number. This number appears only on this record.  # noqa: E501

        :return: The mobile_phone of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._mobile_phone

    @mobile_phone.setter
    def mobile_phone(self, mobile_phone):
        """Sets the mobile_phone of this Contact.

        Enter the contact&apos;s mobile or cell phone number. This number appears only on this record.  # noqa: E501

        :param mobile_phone: The mobile_phone of this Contact.  # noqa: E501
        :type: str
        """

        self._mobile_phone = mobile_phone

    @property
    def custentity_pre_requisites_certs(self):
        """Gets the custentity_pre_requisites_certs of this Contact.  # noqa: E501


        :return: The custentity_pre_requisites_certs of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_pre_requisites_certs

    @custentity_pre_requisites_certs.setter
    def custentity_pre_requisites_certs(self, custentity_pre_requisites_certs):
        """Sets the custentity_pre_requisites_certs of this Contact.


        :param custentity_pre_requisites_certs: The custentity_pre_requisites_certs of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_pre_requisites_certs = custentity_pre_requisites_certs

    @property
    def custentity_ph_nvq3(self):
        """Gets the custentity_ph_nvq3 of this Contact.  # noqa: E501


        :return: The custentity_ph_nvq3 of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_ph_nvq3

    @custentity_ph_nvq3.setter
    def custentity_ph_nvq3(self, custentity_ph_nvq3):
        """Sets the custentity_ph_nvq3 of this Contact.


        :param custentity_ph_nvq3: The custentity_ph_nvq3 of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_ph_nvq3 = custentity_ph_nvq3

    @property
    def custentity_salutation_workaround(self):
        """Gets the custentity_salutation_workaround of this Contact.  # noqa: E501


        :return: The custentity_salutation_workaround of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_salutation_workaround

    @custentity_salutation_workaround.setter
    def custentity_salutation_workaround(self, custentity_salutation_workaround):
        """Sets the custentity_salutation_workaround of this Contact.


        :param custentity_salutation_workaround: The custentity_salutation_workaround of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_salutation_workaround = custentity_salutation_workaround

    @property
    def custentity_mcs_number(self):
        """Gets the custentity_mcs_number of this Contact.  # noqa: E501


        :return: The custentity_mcs_number of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_mcs_number

    @custentity_mcs_number.setter
    def custentity_mcs_number(self, custentity_mcs_number):
        """Sets the custentity_mcs_number of this Contact.


        :param custentity_mcs_number: The custentity_mcs_number of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_mcs_number = custentity_mcs_number

    @property
    def global_subscription_status(self):
        """Gets the global_subscription_status of this Contact.  # noqa: E501


        :return: The global_subscription_status of this Contact.  # noqa: E501
        :rtype: CustomerGlobalSubscriptionStatus
        """
        return self._global_subscription_status

    @global_subscription_status.setter
    def global_subscription_status(self, global_subscription_status):
        """Sets the global_subscription_status of this Contact.


        :param global_subscription_status: The global_subscription_status of this Contact.  # noqa: E501
        :type: CustomerGlobalSubscriptionStatus
        """

        self._global_subscription_status = global_subscription_status

    @property
    def custentity_ph_nvq2(self):
        """Gets the custentity_ph_nvq2 of this Contact.  # noqa: E501


        :return: The custentity_ph_nvq2 of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_ph_nvq2

    @custentity_ph_nvq2.setter
    def custentity_ph_nvq2(self, custentity_ph_nvq2):
        """Sets the custentity_ph_nvq2 of this Contact.


        :param custentity_ph_nvq2: The custentity_ph_nvq2 of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_ph_nvq2 = custentity_ph_nvq2

    @property
    def custentity_send_emp_sms(self):
        """Gets the custentity_send_emp_sms of this Contact.  # noqa: E501


        :return: The custentity_send_emp_sms of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_send_emp_sms

    @custentity_send_emp_sms.setter
    def custentity_send_emp_sms(self, custentity_send_emp_sms):
        """Sets the custentity_send_emp_sms of this Contact.


        :param custentity_send_emp_sms: The custentity_send_emp_sms of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_send_emp_sms = custentity_send_emp_sms

    @property
    def alt_email(self):
        """Gets the alt_email of this Contact.  # noqa: E501

        &lt;p&gt;Enter an alternate email address for this contact. If you use the Capture Email Replies, email sent with the alternate email address are automatically attached to the contact record.  # noqa: E501

        :return: The alt_email of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._alt_email

    @alt_email.setter
    def alt_email(self, alt_email):
        """Sets the alt_email of this Contact.

        &lt;p&gt;Enter an alternate email address for this contact. If you use the Capture Email Replies, email sent with the alternate email address are automatically attached to the contact record.  # noqa: E501

        :param alt_email: The alt_email of this Contact.  # noqa: E501
        :type: str
        """

        self._alt_email = alt_email

    @property
    def custentityniceic_accreditation_date(self):
        """Gets the custentityniceic_accreditation_date of this Contact.  # noqa: E501


        :return: The custentityniceic_accreditation_date of this Contact.  # noqa: E501
        :rtype: date
        """
        return self._custentityniceic_accreditation_date

    @custentityniceic_accreditation_date.setter
    def custentityniceic_accreditation_date(self, custentityniceic_accreditation_date):
        """Sets the custentityniceic_accreditation_date of this Contact.


        :param custentityniceic_accreditation_date: The custentityniceic_accreditation_date of this Contact.  # noqa: E501
        :type: date
        """

        self._custentityniceic_accreditation_date = custentityniceic_accreditation_date

    @property
    def custentity_hp_qual_details(self):
        """Gets the custentity_hp_qual_details of this Contact.  # noqa: E501


        :return: The custentity_hp_qual_details of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_hp_qual_details

    @custentity_hp_qual_details.setter
    def custentity_hp_qual_details(self, custentity_hp_qual_details):
        """Sets the custentity_hp_qual_details of this Contact.


        :param custentity_hp_qual_details: The custentity_hp_qual_details of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_hp_qual_details = custentity_hp_qual_details

    @property
    def salutation(self):
        """Gets the salutation of this Contact.  # noqa: E501

        Enter the contact&apos;s salutation. Examples are Mr., Mrs., Ms. and Miss.  # noqa: E501

        :return: The salutation of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._salutation

    @salutation.setter
    def salutation(self, salutation):
        """Sets the salutation of this Contact.

        Enter the contact&apos;s salutation. Examples are Mr., Mrs., Ms. and Miss.  # noqa: E501

        :param salutation: The salutation of this Contact.  # noqa: E501
        :type: str
        """

        self._salutation = salutation

    @property
    def custentity_hp_instll_prev_yn(self):
        """Gets the custentity_hp_instll_prev_yn of this Contact.  # noqa: E501


        :return: The custentity_hp_instll_prev_yn of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_hp_instll_prev_yn

    @custentity_hp_instll_prev_yn.setter
    def custentity_hp_instll_prev_yn(self, custentity_hp_instll_prev_yn):
        """Sets the custentity_hp_instll_prev_yn of this Contact.


        :param custentity_hp_instll_prev_yn: The custentity_hp_instll_prev_yn of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_hp_instll_prev_yn = custentity_hp_instll_prev_yn

    @property
    def custentity_website_qr_number(self):
        """Gets the custentity_website_qr_number of this Contact.  # noqa: E501


        :return: The custentity_website_qr_number of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_website_qr_number

    @custentity_website_qr_number.setter
    def custentity_website_qr_number(self, custentity_website_qr_number):
        """Sets the custentity_website_qr_number of this Contact.


        :param custentity_website_qr_number: The custentity_website_qr_number of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_website_qr_number = custentity_website_qr_number

    @property
    def custentity_feedback_completed(self):
        """Gets the custentity_feedback_completed of this Contact.  # noqa: E501


        :return: The custentity_feedback_completed of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_feedback_completed

    @custentity_feedback_completed.setter
    def custentity_feedback_completed(self, custentity_feedback_completed):
        """Sets the custentity_feedback_completed of this Contact.


        :param custentity_feedback_completed: The custentity_feedback_completed of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_feedback_completed = custentity_feedback_completed

    @property
    def is_inactive(self):
        """Gets the is_inactive of this Contact.  # noqa: E501

        When you check this box, this contact no longer appears on the Contacts list unless you check the Show Inactives box at the bottom of the page. Also, you can no longer select this contact from lists on transactions, company records, task records or events records.  # noqa: E501

        :return: The is_inactive of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._is_inactive

    @is_inactive.setter
    def is_inactive(self, is_inactive):
        """Sets the is_inactive of this Contact.

        When you check this box, this contact no longer appears on the Contacts list unless you check the Show Inactives box at the bottom of the page. Also, you can no longer select this contact from lists on transactions, company records, task records or events records.  # noqa: E501

        :param is_inactive: The is_inactive of this Contact.  # noqa: E501
        :type: bool
        """

        self._is_inactive = is_inactive

    @property
    def first_name(self):
        """Gets the first_name of this Contact.  # noqa: E501

        Enter the contact&apos;s name. What you enter here automatically appears first in the Contact field. This field is required for the Online Bill Pay feature.  # noqa: E501

        :return: The first_name of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this Contact.

        Enter the contact&apos;s name. What you enter here automatically appears first in the Contact field. This field is required for the Online Bill Pay feature.  # noqa: E501

        :param first_name: The first_name of this Contact.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def home_phone(self):
        """Gets the home_phone of this Contact.  # noqa: E501

        Enter the contact&apos;s home phone number. This number appears only on this record.  # noqa: E501

        :return: The home_phone of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._home_phone

    @home_phone.setter
    def home_phone(self, home_phone):
        """Sets the home_phone of this Contact.

        Enter the contact&apos;s home phone number. This number appears only on this record.  # noqa: E501

        :param home_phone: The home_phone of this Contact.  # noqa: E501
        :type: str
        """

        self._home_phone = home_phone

    @property
    def custentity_mm_smsreplystatus(self):
        """Gets the custentity_mm_smsreplystatus of this Contact.  # noqa: E501


        :return: The custentity_mm_smsreplystatus of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_mm_smsreplystatus

    @custentity_mm_smsreplystatus.setter
    def custentity_mm_smsreplystatus(self, custentity_mm_smsreplystatus):
        """Sets the custentity_mm_smsreplystatus of this Contact.


        :param custentity_mm_smsreplystatus: The custentity_mm_smsreplystatus of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_mm_smsreplystatus = custentity_mm_smsreplystatus

    @property
    def custentity_pv_qual_details(self):
        """Gets the custentity_pv_qual_details of this Contact.  # noqa: E501


        :return: The custentity_pv_qual_details of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_pv_qual_details

    @custentity_pv_qual_details.setter
    def custentity_pv_qual_details(self, custentity_pv_qual_details):
        """Sets the custentity_pv_qual_details of this Contact.


        :param custentity_pv_qual_details: The custentity_pv_qual_details of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_pv_qual_details = custentity_pv_qual_details

    @property
    def custentityent_mobile_phone(self):
        """Gets the custentityent_mobile_phone of this Contact.  # noqa: E501


        :return: The custentityent_mobile_phone of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentityent_mobile_phone

    @custentityent_mobile_phone.setter
    def custentityent_mobile_phone(self, custentityent_mobile_phone):
        """Sets the custentityent_mobile_phone of this Contact.


        :param custentityent_mobile_phone: The custentityent_mobile_phone of this Contact.  # noqa: E501
        :type: str
        """

        self._custentityent_mobile_phone = custentityent_mobile_phone

    @property
    def custentity_health_safety_coshh(self):
        """Gets the custentity_health_safety_coshh of this Contact.  # noqa: E501


        :return: The custentity_health_safety_coshh of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_health_safety_coshh

    @custentity_health_safety_coshh.setter
    def custentity_health_safety_coshh(self, custentity_health_safety_coshh):
        """Sets the custentity_health_safety_coshh of this Contact.


        :param custentity_health_safety_coshh: The custentity_health_safety_coshh of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_health_safety_coshh = custentity_health_safety_coshh

    @property
    def title(self):
        """Gets the title of this Contact.  # noqa: E501

        Enter this contact&apos;s title at his or her company. On the record for this contact&apos;s company, in the Contacts section, this title appears next to the contacts name.  # noqa: E501

        :return: The title of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Contact.

        Enter this contact&apos;s title at his or her company. On the record for this contact&apos;s company, in the Contacts section, this title appears next to the contacts name.  # noqa: E501

        :param title: The title of this Contact.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def custentity_nat_ins(self):
        """Gets the custentity_nat_ins of this Contact.  # noqa: E501


        :return: The custentity_nat_ins of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_nat_ins

    @custentity_nat_ins.setter
    def custentity_nat_ins(self, custentity_nat_ins):
        """Sets the custentity_nat_ins of this Contact.


        :param custentity_nat_ins: The custentity_nat_ins of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_nat_ins = custentity_nat_ins

    @property
    def custentityka_ranking(self):
        """Gets the custentityka_ranking of this Contact.  # noqa: E501


        :return: The custentityka_ranking of this Contact.  # noqa: E501
        :rtype: int
        """
        return self._custentityka_ranking

    @custentityka_ranking.setter
    def custentityka_ranking(self, custentityka_ranking):
        """Sets the custentityka_ranking of this Contact.


        :param custentityka_ranking: The custentityka_ranking of this Contact.  # noqa: E501
        :type: int
        """

        self._custentityka_ranking = custentityka_ranking

    @property
    def custentity_health_safety_man_hdling(self):
        """Gets the custentity_health_safety_man_hdling of this Contact.  # noqa: E501


        :return: The custentity_health_safety_man_hdling of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_health_safety_man_hdling

    @custentity_health_safety_man_hdling.setter
    def custentity_health_safety_man_hdling(self, custentity_health_safety_man_hdling):
        """Sets the custentity_health_safety_man_hdling of this Contact.


        :param custentity_health_safety_man_hdling: The custentity_health_safety_man_hdling of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_health_safety_man_hdling = custentity_health_safety_man_hdling

    @property
    def custentity_dob(self):
        """Gets the custentity_dob of this Contact.  # noqa: E501


        :return: The custentity_dob of this Contact.  # noqa: E501
        :rtype: date
        """
        return self._custentity_dob

    @custentity_dob.setter
    def custentity_dob(self, custentity_dob):
        """Sets the custentity_dob of this Contact.


        :param custentity_dob: The custentity_dob of this Contact.  # noqa: E501
        :type: date
        """

        self._custentity_dob = custentity_dob

    @property
    def custentity_sales_rep_email(self):
        """Gets the custentity_sales_rep_email of this Contact.  # noqa: E501


        :return: The custentity_sales_rep_email of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_sales_rep_email

    @custentity_sales_rep_email.setter
    def custentity_sales_rep_email(self, custentity_sales_rep_email):
        """Sets the custentity_sales_rep_email of this Contact.


        :param custentity_sales_rep_email: The custentity_sales_rep_email of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_sales_rep_email = custentity_sales_rep_email

    @property
    def owner(self):
        """Gets the owner of this Contact.  # noqa: E501


        :return: The owner of this Contact.  # noqa: E501
        :rtype: int
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this Contact.


        :param owner: The owner of this Contact.  # noqa: E501
        :type: int
        """

        self._owner = owner

    @property
    def comments(self):
        """Gets the comments of this Contact.  # noqa: E501

        Enter any other information you want to note about this contact. These notes appears only on this record. You can enter up to 999 characters of text.  # noqa: E501

        :return: The comments of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """Sets the comments of this Contact.

        Enter any other information you want to note about this contact. These notes appears only on this record. You can enter up to 999 characters of text.  # noqa: E501

        :param comments: The comments of this Contact.  # noqa: E501
        :type: str
        """

        self._comments = comments

    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this Contact.  # noqa: E501


        :return: The last_modified_date of this Contact.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this Contact.


        :param last_modified_date: The last_modified_date of this Contact.  # noqa: E501
        :type: datetime
        """

        self._last_modified_date = last_modified_date

    @property
    def custentity_send_emp_email(self):
        """Gets the custentity_send_emp_email of this Contact.  # noqa: E501


        :return: The custentity_send_emp_email of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_send_emp_email

    @custentity_send_emp_email.setter
    def custentity_send_emp_email(self, custentity_send_emp_email):
        """Sets the custentity_send_emp_email of this Contact.


        :param custentity_send_emp_email: The custentity_send_emp_email of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_send_emp_email = custentity_send_emp_email

    @property
    def middle_name(self):
        """Gets the middle_name of this Contact.  # noqa: E501

        Enter the contact&apos;s middle name or initial. This field is optional. What you enter here automatically appears second in the Contact field.  # noqa: E501

        :return: The middle_name of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._middle_name

    @middle_name.setter
    def middle_name(self, middle_name):
        """Sets the middle_name of this Contact.

        Enter the contact&apos;s middle name or initial. This field is optional. What you enter here automatically appears second in the Contact field.  # noqa: E501

        :param middle_name: The middle_name of this Contact.  # noqa: E501
        :type: str
        """

        self._middle_name = middle_name

    @property
    def custentity_resubscribestatus(self):
        """Gets the custentity_resubscribestatus of this Contact.  # noqa: E501


        :return: The custentity_resubscribestatus of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_resubscribestatus

    @custentity_resubscribestatus.setter
    def custentity_resubscribestatus(self, custentity_resubscribestatus):
        """Sets the custentity_resubscribestatus of this Contact.


        :param custentity_resubscribestatus: The custentity_resubscribestatus of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_resubscribestatus = custentity_resubscribestatus

    @property
    def custentity_learning_needs(self):
        """Gets the custentity_learning_needs of this Contact.  # noqa: E501


        :return: The custentity_learning_needs of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_learning_needs

    @custentity_learning_needs.setter
    def custentity_learning_needs(self, custentity_learning_needs):
        """Sets the custentity_learning_needs of this Contact.


        :param custentity_learning_needs: The custentity_learning_needs of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_learning_needs = custentity_learning_needs

    @property
    def custentity_future_of_business(self):
        """Gets the custentity_future_of_business of this Contact.  # noqa: E501


        :return: The custentity_future_of_business of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_future_of_business

    @custentity_future_of_business.setter
    def custentity_future_of_business(self, custentity_future_of_business):
        """Sets the custentity_future_of_business of this Contact.


        :param custentity_future_of_business: The custentity_future_of_business of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_future_of_business = custentity_future_of_business

    @property
    def custentity_no_engineers(self):
        """Gets the custentity_no_engineers of this Contact.  # noqa: E501


        :return: The custentity_no_engineers of this Contact.  # noqa: E501
        :rtype: int
        """
        return self._custentity_no_engineers

    @custentity_no_engineers.setter
    def custentity_no_engineers(self, custentity_no_engineers):
        """Sets the custentity_no_engineers of this Contact.


        :param custentity_no_engineers: The custentity_no_engineers of this Contact.  # noqa: E501
        :type: int
        """

        self._custentity_no_engineers = custentity_no_engineers

    @property
    def custentity_course_comments(self):
        """Gets the custentity_course_comments of this Contact.  # noqa: E501


        :return: The custentity_course_comments of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._custentity_course_comments

    @custentity_course_comments.setter
    def custentity_course_comments(self, custentity_course_comments):
        """Sets the custentity_course_comments of this Contact.


        :param custentity_course_comments: The custentity_course_comments of this Contact.  # noqa: E501
        :type: str
        """

        self._custentity_course_comments = custentity_course_comments

    @property
    def office_phone(self):
        """Gets the office_phone of this Contact.  # noqa: E501

        Enter the contact&apos;s work phone number. This number appears only on this record.  # noqa: E501

        :return: The office_phone of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._office_phone

    @office_phone.setter
    def office_phone(self, office_phone):
        """Sets the office_phone of this Contact.

        Enter the contact&apos;s work phone number. This number appears only on this record.  # noqa: E501

        :param office_phone: The office_phone of this Contact.  # noqa: E501
        :type: str
        """

        self._office_phone = office_phone

    @property
    def custentity_ri_partp_reg(self):
        """Gets the custentity_ri_partp_reg of this Contact.  # noqa: E501


        :return: The custentity_ri_partp_reg of this Contact.  # noqa: E501
        :rtype: bool
        """
        return self._custentity_ri_partp_reg

    @custentity_ri_partp_reg.setter
    def custentity_ri_partp_reg(self, custentity_ri_partp_reg):
        """Sets the custentity_ri_partp_reg of this Contact.


        :param custentity_ri_partp_reg: The custentity_ri_partp_reg of this Contact.  # noqa: E501
        :type: bool
        """

        self._custentity_ri_partp_reg = custentity_ri_partp_reg

    @property
    def supervisor_phone(self):
        """Gets the supervisor_phone of this Contact.  # noqa: E501

        Enter the phone number for this contact&apos;s supervisor.  # noqa: E501

        :return: The supervisor_phone of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._supervisor_phone

    @supervisor_phone.setter
    def supervisor_phone(self, supervisor_phone):
        """Sets the supervisor_phone of this Contact.

        Enter the phone number for this contact&apos;s supervisor.  # noqa: E501

        :param supervisor_phone: The supervisor_phone of this Contact.  # noqa: E501
        :type: str
        """

        self._supervisor_phone = supervisor_phone

    @property
    def ref_name(self):
        """Gets the ref_name of this Contact.  # noqa: E501


        :return: The ref_name of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._ref_name

    @ref_name.setter
    def ref_name(self, ref_name):
        """Sets the ref_name of this Contact.


        :param ref_name: The ref_name of this Contact.  # noqa: E501
        :type: str
        """

        self._ref_name = ref_name

    @property
    def links(self):
        """Gets the links of this Contact.  # noqa: E501


        :return: The links of this Contact.  # noqa: E501
        :rtype: list[NsLink]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this Contact.


        :param links: The links of this Contact.  # noqa: E501
        :type: list[NsLink]
        """

        self._links = links

    @property
    def custentity_pv_course_atteneded(self):
        """Gets the custentity_pv_course_atteneded of this Contact.  # noqa: E501


        :return: The custentity_pv_course_atteneded of this Contact.  # noqa: E501
        :rtype: OneOfcontactCustentityPvCourseAtteneded
        """
        return self._custentity_pv_course_atteneded

    @custentity_pv_course_atteneded.setter
    def custentity_pv_course_atteneded(self, custentity_pv_course_atteneded):
        """Sets the custentity_pv_course_atteneded of this Contact.


        :param custentity_pv_course_atteneded: The custentity_pv_course_atteneded of this Contact.  # noqa: E501
        :type: OneOfcontactCustentityPvCourseAtteneded
        """

        self._custentity_pv_course_atteneded = custentity_pv_course_atteneded

    @property
    def contact_campaign_event(self):
        """Gets the contact_campaign_event of this Contact.  # noqa: E501


        :return: The contact_campaign_event of this Contact.  # noqa: E501
        :rtype: NsResource
        """
        return self._contact_campaign_event

    @contact_campaign_event.setter
    def contact_campaign_event(self, contact_campaign_event):
        """Sets the contact_campaign_event of this Contact.


        :param contact_campaign_event: The contact_campaign_event of this Contact.  # noqa: E501
        :type: NsResource
        """

        self._contact_campaign_event = contact_campaign_event

    @property
    def custentity_further_training_offer(self):
        """Gets the custentity_further_training_offer of this Contact.  # noqa: E501


        :return: The custentity_further_training_offer of this Contact.  # noqa: E501
        :rtype: NsResourceCollection
        """
        return self._custentity_further_training_offer

    @custentity_further_training_offer.setter
    def custentity_further_training_offer(self, custentity_further_training_offer):
        """Sets the custentity_further_training_offer of this Contact.


        :param custentity_further_training_offer: The custentity_further_training_offer of this Contact.  # noqa: E501
        :type: NsResourceCollection
        """

        self._custentity_further_training_offer = custentity_further_training_offer

    @property
    def supervisor(self):
        """Gets the supervisor of this Contact.  # noqa: E501


        :return: The supervisor of this Contact.  # noqa: E501
        :rtype: Contact
        """
        return self._supervisor

    @supervisor.setter
    def supervisor(self, supervisor):
        """Sets the supervisor of this Contact.


        :param supervisor: The supervisor of this Contact.  # noqa: E501
        :type: Contact
        """

        self._supervisor = supervisor

    @property
    def company(self):
        """Gets the company of this Contact.  # noqa: E501


        :return: The company of this Contact.  # noqa: E501
        :rtype: OneOfcontactCompany
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this Contact.


        :param company: The company of this Contact.  # noqa: E501
        :type: OneOfcontactCompany
        """

        self._company = company

    @property
    def contact_source(self):
        """Gets the contact_source of this Contact.  # noqa: E501


        :return: The contact_source of this Contact.  # noqa: E501
        :rtype: NsResource
        """
        return self._contact_source

    @contact_source.setter
    def contact_source(self, contact_source):
        """Sets the contact_source of this Contact.


        :param contact_source: The contact_source of this Contact.  # noqa: E501
        :type: NsResource
        """

        self._contact_source = contact_source

    @property
    def image(self):
        """Gets the image of this Contact.  # noqa: E501


        :return: The image of this Contact.  # noqa: E501
        :rtype: NsResource
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this Contact.


        :param image: The image of this Contact.  # noqa: E501
        :type: NsResource
        """

        self._image = image

    @property
    def custentity_scope_of_business(self):
        """Gets the custentity_scope_of_business of this Contact.  # noqa: E501


        :return: The custentity_scope_of_business of this Contact.  # noqa: E501
        :rtype: NsResource
        """
        return self._custentity_scope_of_business

    @custentity_scope_of_business.setter
    def custentity_scope_of_business(self, custentity_scope_of_business):
        """Sets the custentity_scope_of_business of this Contact.


        :param custentity_scope_of_business: The custentity_scope_of_business of this Contact.  # noqa: E501
        :type: NsResource
        """

        self._custentity_scope_of_business = custentity_scope_of_business

    @property
    def custentity_dietry_requirements(self):
        """Gets the custentity_dietry_requirements of this Contact.  # noqa: E501


        :return: The custentity_dietry_requirements of this Contact.  # noqa: E501
        :rtype: NsResource
        """
        return self._custentity_dietry_requirements

    @custentity_dietry_requirements.setter
    def custentity_dietry_requirements(self, custentity_dietry_requirements):
        """Sets the custentity_dietry_requirements of this Contact.


        :param custentity_dietry_requirements: The custentity_dietry_requirements of this Contact.  # noqa: E501
        :type: NsResource
        """

        self._custentity_dietry_requirements = custentity_dietry_requirements

    @property
    def custentity_heat_pump_training(self):
        """Gets the custentity_heat_pump_training of this Contact.  # noqa: E501


        :return: The custentity_heat_pump_training of this Contact.  # noqa: E501
        :rtype: NsResource
        """
        return self._custentity_heat_pump_training

    @custentity_heat_pump_training.setter
    def custentity_heat_pump_training(self, custentity_heat_pump_training):
        """Sets the custentity_heat_pump_training of this Contact.


        :param custentity_heat_pump_training: The custentity_heat_pump_training of this Contact.  # noqa: E501
        :type: NsResource
        """

        self._custentity_heat_pump_training = custentity_heat_pump_training

    @property
    def assistant(self):
        """Gets the assistant of this Contact.  # noqa: E501


        :return: The assistant of this Contact.  # noqa: E501
        :rtype: Contact
        """
        return self._assistant

    @assistant.setter
    def assistant(self, assistant):
        """Sets the assistant of this Contact.


        :param assistant: The assistant of this Contact.  # noqa: E501
        :type: Contact
        """

        self._assistant = assistant

    @property
    def contact_source_campaign_category(self):
        """Gets the contact_source_campaign_category of this Contact.  # noqa: E501


        :return: The contact_source_campaign_category of this Contact.  # noqa: E501
        :rtype: NsResource
        """
        return self._contact_source_campaign_category

    @contact_source_campaign_category.setter
    def contact_source_campaign_category(self, contact_source_campaign_category):
        """Sets the contact_source_campaign_category of this Contact.


        :param contact_source_campaign_category: The contact_source_campaign_category of this Contact.  # noqa: E501
        :type: NsResource
        """

        self._contact_source_campaign_category = contact_source_campaign_category

    @property
    def custentity_course_attended(self):
        """Gets the custentity_course_attended of this Contact.  # noqa: E501


        :return: The custentity_course_attended of this Contact.  # noqa: E501
        :rtype: OneOfcontactCustentityCourseAttended
        """
        return self._custentity_course_attended

    @custentity_course_attended.setter
    def custentity_course_attended(self, custentity_course_attended):
        """Sets the custentity_course_attended of this Contact.


        :param custentity_course_attended: The custentity_course_attended of this Contact.  # noqa: E501
        :type: OneOfcontactCustentityCourseAttended
        """

        self._custentity_course_attended = custentity_course_attended

    @property
    def custentity_sol_course_attended(self):
        """Gets the custentity_sol_course_attended of this Contact.  # noqa: E501


        :return: The custentity_sol_course_attended of this Contact.  # noqa: E501
        :rtype: OneOfcontactCustentitySolCourseAttended
        """
        return self._custentity_sol_course_attended

    @custentity_sol_course_attended.setter
    def custentity_sol_course_attended(self, custentity_sol_course_attended):
        """Sets the custentity_sol_course_attended of this Contact.


        :param custentity_sol_course_attended: The custentity_sol_course_attended of this Contact.  # noqa: E501
        :type: OneOfcontactCustentitySolCourseAttended
        """

        self._custentity_sol_course_attended = custentity_sol_course_attended

    @property
    def custentity_water_regulations_1999(self):
        """Gets the custentity_water_regulations_1999 of this Contact.  # noqa: E501


        :return: The custentity_water_regulations_1999 of this Contact.  # noqa: E501
        :rtype: OneOfcontactCustentityWaterRegulations1999
        """
        return self._custentity_water_regulations_1999

    @custentity_water_regulations_1999.setter
    def custentity_water_regulations_1999(self, custentity_water_regulations_1999):
        """Sets the custentity_water_regulations_1999 of this Contact.


        :param custentity_water_regulations_1999: The custentity_water_regulations_1999 of this Contact.  # noqa: E501
        :type: OneOfcontactCustentityWaterRegulations1999
        """

        self._custentity_water_regulations_1999 = custentity_water_regulations_1999

    @property
    def custentity_cust_instll_training(self):
        """Gets the custentity_cust_instll_training of this Contact.  # noqa: E501


        :return: The custentity_cust_instll_training of this Contact.  # noqa: E501
        :rtype: NsResource
        """
        return self._custentity_cust_instll_training

    @custentity_cust_instll_training.setter
    def custentity_cust_instll_training(self, custentity_cust_instll_training):
        """Sets the custentity_cust_instll_training of this Contact.


        :param custentity_cust_instll_training: The custentity_cust_instll_training of this Contact.  # noqa: E501
        :type: NsResource
        """

        self._custentity_cust_instll_training = custentity_cust_instll_training

    @property
    def custentityent_bestcontact(self):
        """Gets the custentityent_bestcontact of this Contact.  # noqa: E501


        :return: The custentityent_bestcontact of this Contact.  # noqa: E501
        :rtype: NsResource
        """
        return self._custentityent_bestcontact

    @custentityent_bestcontact.setter
    def custentityent_bestcontact(self, custentityent_bestcontact):
        """Sets the custentityent_bestcontact of this Contact.


        :param custentityent_bestcontact: The custentityent_bestcontact of this Contact.  # noqa: E501
        :type: NsResource
        """

        self._custentityent_bestcontact = custentityent_bestcontact

    @property
    def custentity_energy_eff_attended(self):
        """Gets the custentity_energy_eff_attended of this Contact.  # noqa: E501


        :return: The custentity_energy_eff_attended of this Contact.  # noqa: E501
        :rtype: OneOfcontactCustentityEnergyEffAttended
        """
        return self._custentity_energy_eff_attended

    @custentity_energy_eff_attended.setter
    def custentity_energy_eff_attended(self, custentity_energy_eff_attended):
        """Sets the custentity_energy_eff_attended of this Contact.


        :param custentity_energy_eff_attended: The custentity_energy_eff_attended of this Contact.  # noqa: E501
        :type: OneOfcontactCustentityEnergyEffAttended
        """

        self._custentity_energy_eff_attended = custentity_energy_eff_attended

    @property
    def custentity_ethnic_group(self):
        """Gets the custentity_ethnic_group of this Contact.  # noqa: E501


        :return: The custentity_ethnic_group of this Contact.  # noqa: E501
        :rtype: NsResource
        """
        return self._custentity_ethnic_group

    @custentity_ethnic_group.setter
    def custentity_ethnic_group(self, custentity_ethnic_group):
        """Sets the custentity_ethnic_group of this Contact.


        :param custentity_ethnic_group: The custentity_ethnic_group of this Contact.  # noqa: E501
        :type: NsResource
        """

        self._custentity_ethnic_group = custentity_ethnic_group

    @property
    def custentity_unvent_hot_water_g3(self):
        """Gets the custentity_unvent_hot_water_g3 of this Contact.  # noqa: E501


        :return: The custentity_unvent_hot_water_g3 of this Contact.  # noqa: E501
        :rtype: OneOfcontactCustentityUnventHotWaterG3
        """
        return self._custentity_unvent_hot_water_g3

    @custentity_unvent_hot_water_g3.setter
    def custentity_unvent_hot_water_g3(self, custentity_unvent_hot_water_g3):
        """Sets the custentity_unvent_hot_water_g3 of this Contact.


        :param custentity_unvent_hot_water_g3: The custentity_unvent_hot_water_g3 of this Contact.  # noqa: E501
        :type: OneOfcontactCustentityUnventHotWaterG3
        """

        self._custentity_unvent_hot_water_g3 = custentity_unvent_hot_water_g3

    @property
    def category(self):
        """Gets the category of this Contact.  # noqa: E501


        :return: The category of this Contact.  # noqa: E501
        :rtype: NsResourceCollection
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Contact.


        :param category: The category of this Contact.  # noqa: E501
        :type: NsResourceCollection
        """

        self._category = category

    @property
    def custentity_hp_course_attended(self):
        """Gets the custentity_hp_course_attended of this Contact.  # noqa: E501


        :return: The custentity_hp_course_attended of this Contact.  # noqa: E501
        :rtype: OneOfcontactCustentityHpCourseAttended
        """
        return self._custentity_hp_course_attended

    @custentity_hp_course_attended.setter
    def custentity_hp_course_attended(self, custentity_hp_course_attended):
        """Sets the custentity_hp_course_attended of this Contact.


        :param custentity_hp_course_attended: The custentity_hp_course_attended of this Contact.  # noqa: E501
        :type: OneOfcontactCustentityHpCourseAttended
        """

        self._custentity_hp_course_attended = custentity_hp_course_attended

    @property
    def custentity_mm_lastsmssentby(self):
        """Gets the custentity_mm_lastsmssentby of this Contact.  # noqa: E501


        :return: The custentity_mm_lastsmssentby of this Contact.  # noqa: E501
        :rtype: NsResource
        """
        return self._custentity_mm_lastsmssentby

    @custentity_mm_lastsmssentby.setter
    def custentity_mm_lastsmssentby(self, custentity_mm_lastsmssentby):
        """Sets the custentity_mm_lastsmssentby of this Contact.


        :param custentity_mm_lastsmssentby: The custentity_mm_lastsmssentby of this Contact.  # noqa: E501
        :type: NsResource
        """

        self._custentity_mm_lastsmssentby = custentity_mm_lastsmssentby

    @property
    def custentity_hitachi_course_attended(self):
        """Gets the custentity_hitachi_course_attended of this Contact.  # noqa: E501


        :return: The custentity_hitachi_course_attended of this Contact.  # noqa: E501
        :rtype: OneOfcontactCustentityHitachiCourseAttended
        """
        return self._custentity_hitachi_course_attended

    @custentity_hitachi_course_attended.setter
    def custentity_hitachi_course_attended(self, custentity_hitachi_course_attended):
        """Sets the custentity_hitachi_course_attended of this Contact.


        :param custentity_hitachi_course_attended: The custentity_hitachi_course_attended of this Contact.  # noqa: E501
        :type: OneOfcontactCustentityHitachiCourseAttended
        """

        self._custentity_hitachi_course_attended = custentity_hitachi_course_attended

    @property
    def subsidiary(self):
        """Gets the subsidiary of this Contact.  # noqa: E501


        :return: The subsidiary of this Contact.  # noqa: E501
        :rtype: NsResource
        """
        return self._subsidiary

    @subsidiary.setter
    def subsidiary(self, subsidiary):
        """Sets the subsidiary of this Contact.


        :param subsidiary: The subsidiary of this Contact.  # noqa: E501
        :type: NsResource
        """

        self._subsidiary = subsidiary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Contact, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Contact):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""
Settings for Netsuite SDK are all namespaced in the NETSUITE setting.
For example your project's `settings.py` file might look like this:

NETSUITE = {
    'DEFAULT_STORAGE_CLASSES': [
        'netsuite.storages.JSONStorage',
    ],
}

This module provides the `api_setting` object, that is used to access
NETSUITE settings, checking for user settings first, then falling
back to the defaults.
"""
from .module_loading import import_string

django_imported = False
try:
    from django.conf import settings
    from django.test.signals import setting_changed
    # from django.utils.module_loading import import_string
    from django.core.exceptions import ImproperlyConfigured

    try:
        getattr(settings, 'NETSUITE', {})
        django_imported = True
    except ImproperlyConfigured as e:
        settings = None
except ImportError as e:
    settings = None


JSON_STORAGE = 'netsuite.storages.JSONStorage'
IN_MEMORY_STORAGE = 'netsuite.storages.InMemoryStorage'
DEFAULTS = {
    # Base API policies
    'DEFAULT_STORAGE_CLASSES': [
        JSON_STORAGE,
        IN_MEMORY_STORAGE,
    ],

    # API Configuration
    'NETSUITE_APP_NAME': None,
    'CLIENT_ID': None,
    'NETSUITE_KEY_FILE': './netsuite-key.pem',
    'CERT_ID': None,
    # 'CLIENT_SECRET': None,
    # 'REDIRECT_URL': 'https://theapiguys.com',

    'ALLOW_NONE': False,
    'USE_DATETIME': True,

    'STORAGE_CLASS': 'netsuite.storages.JSONStorage',
    'CREDENTIALS_PATH': './netsuite-credentials.json',
    'JSON_STORAGE_PATH': './netsuite-tokens.json',
    'NETSUITE_CERTIFICATE_PATH': './netsuite-certificate.pem',

    'APP_NAME': 'default',
}

# List of settings that may be in string import notation.
IMPORT_STRINGS = [
    'DEFAULT_STORAGE_CLASSES',
    'STORAGE_CLASS',
]

# List of settings that have been removed
REMOVED_SETTINGS = [

]


def perform_import(val, setting_name):
    """
    If the given setting is a string import notation,
    then perform the necessary import or imports.
    """
    if val is None:
        return None
    elif isinstance(val, str):
        return import_from_string(val, setting_name)
    elif isinstance(val, (list, tuple)):
        return [import_from_string(item, setting_name) for item in val]
    return val


def import_from_string(val, setting_name):
    """
    Attempt to import a class from a string representation.
    """
    try:
        return import_string(val)
    except ImportError as e:
        msg = "Could not import '%s' for API setting '%s'. %s: %s." % (val, setting_name, e.__class__.__name__, e)
        raise ImportError(msg)


class APISettings:
    """
    A settings object that allows Netsuite settings to be accessed as
    properties. For example:

        from netsuite.settings import api_settings
        print(api_settings.DEFAULT_RENDERER_CLASSES)

    Any setting with string import paths will be automatically resolved
    and return the class, rather than the string literal.

    Note:
    This is an internal class that is only compatible with settings namespaced
    under the NETSUITE name. It is not intended to be used by 3rd-party
    apps, and test helpers like `override_settings` may not work as expected.
    """

    def __init__(self, user_settings=None, defaults=None, import_strings=None):
        if user_settings:
            self._user_settings = self.__check_user_settings(user_settings)
        self.defaults = defaults or DEFAULTS
        self.import_strings = import_strings or IMPORT_STRINGS
        self._cached_attrs = set()

    @property
    def user_settings(self):
        if not hasattr(self, '_user_settings'):
            self._user_settings = getattr(settings, 'NETSUITE', {})
        return self._user_settings

    def __getattr__(self, attr):
        if attr not in self.defaults:
            raise AttributeError("Invalid API setting: '%s'" % attr)

        try:
            # Check if present in user settings
            val = self.user_settings[attr]
        except KeyError:
            # Fall back to defaults
            val = self.defaults[attr]

        # Coerce import strings into classes
        if attr in self.import_strings:
            val = perform_import(val, attr)

        # Cache the result
        self._cached_attrs.add(attr)
        setattr(self, attr, val)
        return val

    def __check_user_settings(self, user_settings):
        SETTINGS_DOC = "https://bitbucket.org/theapiguys/netsuite-python"
        for setting in REMOVED_SETTINGS:
            if setting in user_settings:
                raise RuntimeError("The '%s' setting has been removed. Please refer to '%s' for available settings." % (
                    setting, SETTINGS_DOC))
        return user_settings

    def reload(self):
        for attr in self._cached_attrs:
            delattr(self, attr)
        self._cached_attrs.clear()
        if hasattr(self, '_user_settings'):
            delattr(self, '_user_settings')


api_settings = APISettings(None, DEFAULTS, IMPORT_STRINGS)

if django_imported:
    def reload_api_settings(*args, **kwargs):
        setting = kwargs['setting']
        if setting == 'NETSUITE':
            api_settings.reload()


    setting_changed.connect(reload_api_settings)



# coding: utf-8

"""
    NetSuite REST API

    NetSuite REST Record API generated 2023-01-18 at 19:40:11 UTC for account 472052, user will@theapiguys.com with role Keap Integration.  # noqa: E501

    OpenAPI spec version: v1
    Contact: info@netsuite.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NsErrorOerrorDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'detail': 'str',
        'oerror_path': 'str',
        'oerror_url': 'str',
        'oerror_header': 'str',
        'oerror_query_param': 'str',
        'oerror_code': 'str'
    }

    attribute_map = {
        'detail': 'detail',
        'oerror_path': 'o:errorPath',
        'oerror_url': 'o:errorUrl',
        'oerror_header': 'o:errorHeader',
        'oerror_query_param': 'o:errorQueryParam',
        'oerror_code': 'o:errorCode'
    }

    def __init__(self, detail=None, oerror_path=None, oerror_url=None, oerror_header=None, oerror_query_param=None, oerror_code=None):  # noqa: E501
        """NsErrorOerrorDetails - a model defined in Swagger"""  # noqa: E501
        self._detail = None
        self._oerror_path = None
        self._oerror_url = None
        self._oerror_header = None
        self._oerror_query_param = None
        self._oerror_code = None
        self.discriminator = None
        if detail is not None:
            self.detail = detail
        if oerror_path is not None:
            self.oerror_path = oerror_path
        if oerror_url is not None:
            self.oerror_url = oerror_url
        if oerror_header is not None:
            self.oerror_header = oerror_header
        if oerror_query_param is not None:
            self.oerror_query_param = oerror_query_param
        if oerror_code is not None:
            self.oerror_code = oerror_code

    @property
    def detail(self):
        """Gets the detail of this NsErrorOerrorDetails.  # noqa: E501

        A detailed, human-readable description of the problem occurrence.  # noqa: E501

        :return: The detail of this NsErrorOerrorDetails.  # noqa: E501
        :rtype: str
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this NsErrorOerrorDetails.

        A detailed, human-readable description of the problem occurrence.  # noqa: E501

        :param detail: The detail of this NsErrorOerrorDetails.  # noqa: E501
        :type: str
        """

        self._detail = detail

    @property
    def oerror_path(self):
        """Gets the oerror_path of this NsErrorOerrorDetails.  # noqa: E501

        The JSON path that indicates where the problem occurs within the request body.  # noqa: E501

        :return: The oerror_path of this NsErrorOerrorDetails.  # noqa: E501
        :rtype: str
        """
        return self._oerror_path

    @oerror_path.setter
    def oerror_path(self, oerror_path):
        """Sets the oerror_path of this NsErrorOerrorDetails.

        The JSON path that indicates where the problem occurs within the request body.  # noqa: E501

        :param oerror_path: The oerror_path of this NsErrorOerrorDetails.  # noqa: E501
        :type: str
        """

        self._oerror_path = oerror_path

    @property
    def oerror_url(self):
        """Gets the oerror_url of this NsErrorOerrorDetails.  # noqa: E501

        The URI of the first element in the request URL where the problem occurs.  # noqa: E501

        :return: The oerror_url of this NsErrorOerrorDetails.  # noqa: E501
        :rtype: str
        """
        return self._oerror_url

    @oerror_url.setter
    def oerror_url(self, oerror_url):
        """Sets the oerror_url of this NsErrorOerrorDetails.

        The URI of the first element in the request URL where the problem occurs.  # noqa: E501

        :param oerror_url: The oerror_url of this NsErrorOerrorDetails.  # noqa: E501
        :type: str
        """

        self._oerror_url = oerror_url

    @property
    def oerror_header(self):
        """Gets the oerror_header of this NsErrorOerrorDetails.  # noqa: E501

        The name of the HTTP header where the problem occurs.  # noqa: E501

        :return: The oerror_header of this NsErrorOerrorDetails.  # noqa: E501
        :rtype: str
        """
        return self._oerror_header

    @oerror_header.setter
    def oerror_header(self, oerror_header):
        """Sets the oerror_header of this NsErrorOerrorDetails.

        The name of the HTTP header where the problem occurs.  # noqa: E501

        :param oerror_header: The oerror_header of this NsErrorOerrorDetails.  # noqa: E501
        :type: str
        """

        self._oerror_header = oerror_header

    @property
    def oerror_query_param(self):
        """Gets the oerror_query_param of this NsErrorOerrorDetails.  # noqa: E501

        The name of the query parameter where the problem occurs.  # noqa: E501

        :return: The oerror_query_param of this NsErrorOerrorDetails.  # noqa: E501
        :rtype: str
        """
        return self._oerror_query_param

    @oerror_query_param.setter
    def oerror_query_param(self, oerror_query_param):
        """Sets the oerror_query_param of this NsErrorOerrorDetails.

        The name of the query parameter where the problem occurs.  # noqa: E501

        :param oerror_query_param: The oerror_query_param of this NsErrorOerrorDetails.  # noqa: E501
        :type: str
        """

        self._oerror_query_param = oerror_query_param

    @property
    def oerror_code(self):
        """Gets the oerror_code of this NsErrorOerrorDetails.  # noqa: E501

        The application-specific error code. Similar problem types are grouped together.  # noqa: E501

        :return: The oerror_code of this NsErrorOerrorDetails.  # noqa: E501
        :rtype: str
        """
        return self._oerror_code

    @oerror_code.setter
    def oerror_code(self, oerror_code):
        """Sets the oerror_code of this NsErrorOerrorDetails.

        The application-specific error code. Similar problem types are grouped together.  # noqa: E501

        :param oerror_code: The oerror_code of this NsErrorOerrorDetails.  # noqa: E501
        :type: str
        """

        self._oerror_code = oerror_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NsErrorOerrorDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NsErrorOerrorDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from netsuite.swagger_client.api.contact_api import ContactApi
from netsuite.swagger_client.api.customer_api import CustomerApi
from netsuite.swagger_client.api.message_api import MessageApi



# coding: utf-8

# flake8: noqa
"""
    NetSuite REST API

    NetSuite REST Record API generated 2023-01-18 at 19:40:11 UTC for account 472052, user will@theapiguys.com with role Keap Integration.  # noqa: E501

    OpenAPI spec version: v1
    Contact: info@netsuite.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from netsuite.swagger_client.models.contact import Contact
from netsuite.swagger_client.models.contact_collection import ContactCollection
from netsuite.swagger_client.models.contact_custom_form import ContactCustomForm
from netsuite.swagger_client.models.customer import Customer
from netsuite.swagger_client.models.customer_address_book_address_book_address import CustomerAddressBookAddressBookAddress
from netsuite.swagger_client.models.customer_address_book_collection import CustomerAddressBookCollection
from netsuite.swagger_client.models.customer_address_book_element import CustomerAddressBookElement
from netsuite.swagger_client.models.customer_alcohol_recipient_type import CustomerAlcoholRecipientType
from netsuite.swagger_client.models.customer_campaigns_collection import CustomerCampaignsCollection
from netsuite.swagger_client.models.customer_campaigns_element import CustomerCampaignsElement
from netsuite.swagger_client.models.customer_collection import CustomerCollection
from netsuite.swagger_client.models.customer_contact_roles_collection import CustomerContactRolesCollection
from netsuite.swagger_client.models.customer_contact_roles_element import CustomerContactRolesElement
from netsuite.swagger_client.models.customer_custom_form import CustomerCustomForm
from netsuite.swagger_client.models.customer_email_preference import CustomerEmailPreference
from netsuite.swagger_client.models.customer_global_subscription_status import CustomerGlobalSubscriptionStatus
from netsuite.swagger_client.models.customer_group_pricing_collection import CustomerGroupPricingCollection
from netsuite.swagger_client.models.customer_group_pricing_element import CustomerGroupPricingElement
from netsuite.swagger_client.models.customer_item_pricing_collection import CustomerItemPricingCollection
from netsuite.swagger_client.models.customer_item_pricing_element import CustomerItemPricingElement
from netsuite.swagger_client.models.customer_language import CustomerLanguage
from netsuite.swagger_client.models.customer_negative_number_format import CustomerNegativeNumberFormat
from netsuite.swagger_client.models.customer_number_format import CustomerNumberFormat
from netsuite.swagger_client.models.customer_shipping_carrier import CustomerShippingCarrier
from netsuite.swagger_client.models.customer_symbol_placement import CustomerSymbolPlacement
from netsuite.swagger_client.models.customer_third_party_carrier import CustomerThirdPartyCarrier
from netsuite.swagger_client.models.customeraddress_bookaddress_book_address_country import CustomeraddressBookaddressBookAddressCountry
from netsuite.swagger_client.models.ns_error import NsError
from netsuite.swagger_client.models.ns_error_oerror_details import NsErrorOerrorDetails
from netsuite.swagger_client.models.ns_link import NsLink
from netsuite.swagger_client.models.ns_resource import NsResource
from netsuite.swagger_client.models.ns_resource_collection import NsResourceCollection
from netsuite.swagger_client.models.one_ofcontact_company import OneOfcontactCompany
from netsuite.swagger_client.models.one_ofcontact_custentity_course_attended import OneOfcontactCustentityCourseAttended
from netsuite.swagger_client.models.one_ofcontact_custentity_energy_eff_attended import OneOfcontactCustentityEnergyEffAttended
from netsuite.swagger_client.models.one_ofcontact_custentity_hitachi_course_attended import OneOfcontactCustentityHitachiCourseAttended
from netsuite.swagger_client.models.one_ofcontact_custentity_hp_course_attended import OneOfcontactCustentityHpCourseAttended
from netsuite.swagger_client.models.one_ofcontact_custentity_pv_course_atteneded import OneOfcontactCustentityPvCourseAtteneded
from netsuite.swagger_client.models.one_ofcontact_custentity_sol_course_attended import OneOfcontactCustentitySolCourseAttended
from netsuite.swagger_client.models.one_ofcontact_custentity_unvent_hot_water_g3 import OneOfcontactCustentityUnventHotWaterG3
from netsuite.swagger_client.models.one_ofcontact_custentity_water_regulations1999 import OneOfcontactCustentityWaterRegulations1999
from netsuite.swagger_client.models.one_ofcustomer_custentity_course_attended import OneOfcustomerCustentityCourseAttended
from netsuite.swagger_client.models.one_ofcustomer_custentity_energy_eff_attended import OneOfcustomerCustentityEnergyEffAttended
from netsuite.swagger_client.models.one_ofcustomer_custentity_hitachi_course_attended import OneOfcustomerCustentityHitachiCourseAttended
from netsuite.swagger_client.models.one_ofcustomer_custentity_hp_course_attended import OneOfcustomerCustentityHpCourseAttended
from netsuite.swagger_client.models.one_ofcustomer_custentity_pv_course_atteneded import OneOfcustomerCustentityPvCourseAtteneded
from netsuite.swagger_client.models.one_ofcustomer_custentity_sol_course_attended import OneOfcustomerCustentitySolCourseAttended
from netsuite.swagger_client.models.one_ofcustomer_custentity_unvent_hot_water_g3 import OneOfcustomerCustentityUnventHotWaterG3
from netsuite.swagger_client.models.one_ofcustomer_custentity_water_regulations1999 import OneOfcustomerCustentityWaterRegulations1999
from netsuite.swagger_client.models.one_ofcustomer_item_pricing_element_item import OneOfcustomerItemPricingElementItem
from netsuite.swagger_client.models.message import Message
from netsuite.swagger_client.models.message_collection import MessageCollection
from netsuite.swagger_client.models.one_ofmessage_author import OneOfmessageAuthor
from netsuite.swagger_client.models.one_ofmessage_entity import OneOfmessageEntity
from netsuite.swagger_client.models.one_ofmessage_primary_recipient import OneOfmessagePrimaryRecipient
from netsuite.swagger_client.models.one_ofmessage_recipient import OneOfmessageRecipient


# coding: utf-8

"""
    NetSuite REST API

    NetSuite REST Record API generated 2023-01-18 at 19:40:11 UTC for account 472052, user will@theapiguys.com with role Keap Integration.  # noqa: E501

    OpenAPI spec version: v1
    Contact: info@netsuite.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CustomerAddressBookElement(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'list[NsLink]',
        'internal_id': 'int',
        'default_billing': 'bool',
        'address_book_address_text': 'str',
        'default_shipping': 'bool',
        'is_residential': 'bool',
        'label': 'str',
        'id': 'int',
        'address_id': 'str',
        'ref_name': 'str',
        'address_book_address': 'CustomerAddressBookAddressBookAddress'
    }

    attribute_map = {
        'links': 'links',
        'internal_id': 'internalId',
        'default_billing': 'defaultBilling',
        'address_book_address_text': 'addressBookAddress_text',
        'default_shipping': 'defaultShipping',
        'is_residential': 'isResidential',
        'label': 'label',
        'id': 'id',
        'address_id': 'addressId',
        'ref_name': 'refName',
        'address_book_address': 'addressBookAddress'
    }

    def __init__(self, links=None, internal_id=None, default_billing=None, address_book_address_text=None, default_shipping=None, is_residential=None, label=None, id=None, address_id=None, ref_name=None, address_book_address=None):  # noqa: E501
        """CustomerAddressBookElement - a model defined in Swagger"""  # noqa: E501
        self._links = None
        self._internal_id = None
        self._default_billing = None
        self._address_book_address_text = None
        self._default_shipping = None
        self._is_residential = None
        self._label = None
        self._id = None
        self._address_id = None
        self._ref_name = None
        self._address_book_address = None
        self.discriminator = None
        if links is not None:
            self.links = links
        if internal_id is not None:
            self.internal_id = internal_id
        if default_billing is not None:
            self.default_billing = default_billing
        if address_book_address_text is not None:
            self.address_book_address_text = address_book_address_text
        if default_shipping is not None:
            self.default_shipping = default_shipping
        if is_residential is not None:
            self.is_residential = is_residential
        if label is not None:
            self.label = label
        if id is not None:
            self.id = id
        if address_id is not None:
            self.address_id = address_id
        if ref_name is not None:
            self.ref_name = ref_name
        if address_book_address is not None:
            self.address_book_address = address_book_address

    @property
    def links(self):
        """Gets the links of this CustomerAddressBookElement.  # noqa: E501


        :return: The links of this CustomerAddressBookElement.  # noqa: E501
        :rtype: list[NsLink]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this CustomerAddressBookElement.


        :param links: The links of this CustomerAddressBookElement.  # noqa: E501
        :type: list[NsLink]
        """

        self._links = links

    @property
    def internal_id(self):
        """Gets the internal_id of this CustomerAddressBookElement.  # noqa: E501


        :return: The internal_id of this CustomerAddressBookElement.  # noqa: E501
        :rtype: int
        """
        return self._internal_id

    @internal_id.setter
    def internal_id(self, internal_id):
        """Sets the internal_id of this CustomerAddressBookElement.


        :param internal_id: The internal_id of this CustomerAddressBookElement.  # noqa: E501
        :type: int
        """

        self._internal_id = internal_id

    @property
    def default_billing(self):
        """Gets the default_billing of this CustomerAddressBookElement.  # noqa: E501


        :return: The default_billing of this CustomerAddressBookElement.  # noqa: E501
        :rtype: bool
        """
        return self._default_billing

    @default_billing.setter
    def default_billing(self, default_billing):
        """Sets the default_billing of this CustomerAddressBookElement.


        :param default_billing: The default_billing of this CustomerAddressBookElement.  # noqa: E501
        :type: bool
        """

        self._default_billing = default_billing

    @property
    def address_book_address_text(self):
        """Gets the address_book_address_text of this CustomerAddressBookElement.  # noqa: E501


        :return: The address_book_address_text of this CustomerAddressBookElement.  # noqa: E501
        :rtype: str
        """
        return self._address_book_address_text

    @address_book_address_text.setter
    def address_book_address_text(self, address_book_address_text):
        """Sets the address_book_address_text of this CustomerAddressBookElement.


        :param address_book_address_text: The address_book_address_text of this CustomerAddressBookElement.  # noqa: E501
        :type: str
        """

        self._address_book_address_text = address_book_address_text

    @property
    def default_shipping(self):
        """Gets the default_shipping of this CustomerAddressBookElement.  # noqa: E501


        :return: The default_shipping of this CustomerAddressBookElement.  # noqa: E501
        :rtype: bool
        """
        return self._default_shipping

    @default_shipping.setter
    def default_shipping(self, default_shipping):
        """Sets the default_shipping of this CustomerAddressBookElement.


        :param default_shipping: The default_shipping of this CustomerAddressBookElement.  # noqa: E501
        :type: bool
        """

        self._default_shipping = default_shipping

    @property
    def is_residential(self):
        """Gets the is_residential of this CustomerAddressBookElement.  # noqa: E501


        :return: The is_residential of this CustomerAddressBookElement.  # noqa: E501
        :rtype: bool
        """
        return self._is_residential

    @is_residential.setter
    def is_residential(self, is_residential):
        """Sets the is_residential of this CustomerAddressBookElement.


        :param is_residential: The is_residential of this CustomerAddressBookElement.  # noqa: E501
        :type: bool
        """

        self._is_residential = is_residential

    @property
    def label(self):
        """Gets the label of this CustomerAddressBookElement.  # noqa: E501


        :return: The label of this CustomerAddressBookElement.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this CustomerAddressBookElement.


        :param label: The label of this CustomerAddressBookElement.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def id(self):
        """Gets the id of this CustomerAddressBookElement.  # noqa: E501


        :return: The id of this CustomerAddressBookElement.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CustomerAddressBookElement.


        :param id: The id of this CustomerAddressBookElement.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def address_id(self):
        """Gets the address_id of this CustomerAddressBookElement.  # noqa: E501


        :return: The address_id of this CustomerAddressBookElement.  # noqa: E501
        :rtype: str
        """
        return self._address_id

    @address_id.setter
    def address_id(self, address_id):
        """Sets the address_id of this CustomerAddressBookElement.


        :param address_id: The address_id of this CustomerAddressBookElement.  # noqa: E501
        :type: str
        """

        self._address_id = address_id

    @property
    def ref_name(self):
        """Gets the ref_name of this CustomerAddressBookElement.  # noqa: E501


        :return: The ref_name of this CustomerAddressBookElement.  # noqa: E501
        :rtype: str
        """
        return self._ref_name

    @ref_name.setter
    def ref_name(self, ref_name):
        """Sets the ref_name of this CustomerAddressBookElement.


        :param ref_name: The ref_name of this CustomerAddressBookElement.  # noqa: E501
        :type: str
        """

        self._ref_name = ref_name

    @property
    def address_book_address(self):
        """Gets the address_book_address of this CustomerAddressBookElement.  # noqa: E501


        :return: The address_book_address of this CustomerAddressBookElement.  # noqa: E501
        :rtype: CustomerAddressBookAddressBookAddress
        """
        return self._address_book_address

    @address_book_address.setter
    def address_book_address(self, address_book_address):
        """Sets the address_book_address of this CustomerAddressBookElement.


        :param address_book_address: The address_book_address of this CustomerAddressBookElement.  # noqa: E501
        :type: CustomerAddressBookAddressBookAddress
        """

        self._address_book_address = address_book_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomerAddressBookElement, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomerAddressBookElement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
